<?php

/*
 * @Package: Extraordinary Comments
 * @Plugin URI: http://ckmacleod.com/plugins/extraordinary-comments
 * @Since: 0.91
 * @Author: CK MacLeod
 * @Author URI: http://ckmacleod.com/
 * @License: GPL3, http://www.gnu.org/licenses/gpl.txt
 * Date: October 2016
 * 
*/

defined( 'ABSPATH' ) or die( 'Plugin file cannot be accessed directly.' ) ;

add_shortcode( 'add_exc_archive', 'exc_archive' );

/**
 * EXTRAORDINARY COMMENTS ARCHIVE
 * @param array $atts
 * @return html
 */
function exc_archive( $atts ) { 
    
    $pid = get_the_ID() ;
    
    extract( shortcode_atts( 

        //could be condensed in same way other keys are
        array( 

            'number_comments'   => '',                      //int, how many comments to get in a table - Default is '' or Get All
            'type'              => 'featured',              //what kind of comments to show in table
            'order'             => 'DESC',                  //order in which to display comments: ASC or DESC
            'random'            => 0,                       //display retrieved comments in random order
            'lookback'          => 'January 1, 1970',       //how far back to look for comments ( readable date or expression)
            'lookforward'       => 'January 1, 2038',
            'title'             => '',                      //title of table
            'add_link'          => 0,                       //whether to show a linkback to other category
            'link_label'        => 'View All &rarr;',       //what the link shows
            'link_url'          => esc_url( 
                                    home_url( '/' ) ) 
                                    . 'extraordinary-comments/',        
                                                            //link URL
            'paginate'          => 0,                       //whether to paginate the table ( PAGES ONLY)
            'comments_per_page' => 5,                       //how many comments to show on each page
            'gravatar_size'     => 60,                      //size in pixels of gravatar
            'pre_date'          => '',                      //Unlinked text before the datetime link
            'datetime_format'   => 'l, F j, Y - g:i a',     //datetime format for comment date
            'pre_irt'           => __( 'To ', 'cks_exc' ),  //pre-in-reply-to comment
            'pre_title'         => __( '', 'cks_exc' ),     //pre-post-title text
            'use_excerpt'       => 0,                       //whether to use excerpt instead of content
            'excerpt_length'    => 25,                      //length of excerpt in words
            'continued_label'   => '[...]',                 //label for link to complete comment
            'show_credit'       => 0,                       //whether to show CKs Plugins Credit
            
        ), $atts )

    ) ;
    
    //derivative variables
    $number_to_get = $paginate ? $comments_per_page : '' ;  
    $offset = '';

    if ( $paginate ) {

        $paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

        $offset = ( $paged - 1) * $comments_per_page;

        $total_comments = get_total_comments( 
                $type, $lookback, $lookforward ) ;
        
        $total_pages = intval( $total_comments / $comments_per_page) + 1;

    }

    $comment_query_args = array( 

    'meta_query'    =>  array( 
                            array( 
                                'key'    => $type,
                                'value'  => '1'
                            )
                        ),
    'offset'        =>  $offset,
    'number'        =>  $number_to_get,
    'order'         =>  $order,
    'date_query'    =>  array( 
                            'after'     => $lookback ,
                            'before'    => $lookforward,
                        ),
    );

    $comments = get_comments( apply_filters( 'exc_archive_query_args', 
            $comment_query_args ) ) ;
    
    
    if ( $random && ! $paginate) {

        $comments = cks_exc_shuffle_assoc( $comments ) ;

    }
    
    if ( $number_comments ) {
        
        $comments = array_slice( $comments, 0, $number_comments ) ;
        
    }

    ob_start() ;

    echo '<div id="cks_exc-archive-' . $pid . '" class="cks_exc cks_exc-archive">';

    echo '<h3 class="cks_exc-title cks_exc-title-archive">' 
        . apply_filters( 'cks_exc_archive_title', $title ) . '</h3>' ;
	
    //pagination begin
    if ( $paginate &&  $total_comments > $comments_per_page  ) {
    
        $pagination = cks_exc_pagination( $total_pages ) ;
        
        echo apply_filters( 'cks_exc_archive_pagination_top', $pagination ) ;
    }
    //HEADING 
        
    echo '<div class="cks_exc-comments cks_exc-comments-archive">';
	
	foreach( $comments as $comment) { 
		
            ?>

            <?php do_action( 'cks_exc_archive_comment_before', $comment ) ; ?>

            <div class="cks_exc-comment cks_exc-comment-archive">

                <div class="cks_exc-comment-header cks_exc-comment-header-archive">
                    
                    <?php echo cks_exc_comment_datetime( $comment, $pre_date, 
                            $datetime_format ) ; ?>
                    
                    <?php echo cks_exc_in_reply_to( $comment, $pre_irt ) ; ?>
                    
                    <?php echo cks_exc_post_title( $comment, $pre_title ) ; ?>
                         
                    <?php echo cks_exc_comment_author( 
                            $comment, $gravatar_size 
                            ) ; ?>
                    
                    <?php /* 
                     * PROVISIONAL 
                     * if ( function_exists( 'commenter_archives' ) ) { 
                            
                            show_commenter_archives( $comment ) ;
                            
                        } */ ?>
                    
                </div><!--END HEADER-->
                
                <!--BEGIN BODY-->
                <div class="comment-body cks_exc-comment-body" id="text-<?php 
                    echo $comment->comment_ID ; ?>">
                    
                    <?php 
                    
                    if ( $use_excerpt ) {
                        
                        echo cks_exc_get_exc_comment_text( 
                                $comment, $excerpt_length, $continued_label 
                                ) ;
                        
                        
                    } else {
                    
                        $comment_body = wpautop( $comment->comment_content ) ;
                    
                        echo apply_filters( 
                                'cks_exc_archive_comment_body', $comment_body
                                ) ; 
                    
                    }
                    
                    ?>
                    
                </div><!--end body-->
                
                <?php do_action( 
                        'cks_exc_archive_comment_body_after', $comment 
                        ) ; ?>
                
             </div>   

             <?php do_action( 'cks_exc_archive_comment_after', $comment ) ; ?>
             
             <!-- END COMMENT: use ob_start/apply_filters here) -->

<?php //comment

	} //end foreach
	
	echo '</div>'; //comments

        if ( $add_link ) {
    
    ?>

            <div class="cks_exc-footer cks_exc-footer-archive">

                <a class="cks_exc-linkback cks_exc-linkback-archive" href="<?php 
                echo $link_url ; ?>"><?php 
                echo $link_label ; ?></a>

            </div>


<?php
        }

	//Pagination Bottom general solution from Hongkiat as adapted [1]

	if ( $paginate && $total_comments > $comments_per_page ) {
	
            $pagination = cks_exc_pagination( $total_pages ) ;
        
            echo apply_filters( 'cks_exc_archive_pagination_bottom', 
                    $pagination ) ;
            
	} //end pagination
        
        echo cks_cfix_add_credit( $show_credit ) ;
	
    echo '</div>'; //Extraordinary Comments Archive



//END EXTRAORDINARY COMMENTS ARCHIVE

  $html = ob_get_clean() ;
  
  return apply_filters( 'cks_exc_archive_html', $html ) ;
  
}

/**
 * RANDOMIZATION FUNCTION
 * @param array $list
 * @return array
 */
function cks_exc_shuffle_assoc( $list ) {

    if ( ! is_array( $list ) ) {

        return $list;

    }
    
    $random = array();

    $keys = array_keys( $list );
    
    shuffle( $keys );

    foreach ( $keys as $key) {
        
          $random[$key] = $list[$key] ;
          
    }     
    
    return $random;
    
  }

/**
 * GET TOTAL COMMMENTS REQUESTED
 * helper function for pagination
 * @param string $type
 * @param int $number_comments
 * @param string (date expression) $lookback
 * @param string (date expression) $lookforward
 * @return int
 */  
function get_total_comments( $type, $lookback, $lookforward ) {

    $total_comments_args = array( 

        'number'        =>  '',
        'meta_query'    =>  array( 

                                array( 
                                        'key' => $type,
                                        'value' => '1'
                                )

                            ),   
        'date_query'    =>  array( 

                            'after'     => $lookback ,
                            'before'    => $lookforward,

                            ), 
 
        'count'         =>  TRUE ,

    );
    
    $total_comments = get_comments( $total_comments_args ) ;
    
    return $total_comments ;
    
}

/**
 * PRODUCE PAGINATION LINS
 * @param int $total_pages
 * @return html string
 */
function cks_exc_pagination( $total_pages ) {
    
    $html = '<div class="page_nav clearfix">';
    
    $current_page = max( 1, get_query_var( 'paged' ) );

    $html .= paginate_links( array( 
            'base' => get_pagenum_link( 1) . '%_%',
            'current' => $current_page,
            'total' => $total_pages,
            'prev_text' => __( '&laquo; Previous' ),
            'next_text' => __( 'Next &raquo;' ),
            'end_size' => 2,
            'mid-size' => 3
    ) );
    
    $html .= '</div>'; //pagination end
    
    return $html ;
    
}

function cks_exc_comment_datetime( $comment, $pre_date, $datetime_format ) {
    
    $comment_link = get_comment_link( $comment ) ;
    
    
    $comment_date = mysql2date( $datetime_format, $comment->comment_date ) ;
    
    ob_start() ;
                        
    echo '<div class="comment-datetime cks_exc-comment-datetime">' ;
    
    echo '<span class="cks_exc-pre-date">' . $pre_date . '</span>' ;
    
    echo '<a href="' . $comment_link . '">' ;
    
    echo apply_filters( 'cks_exc_archive_comment_date', 
                                $comment_date, $comment ) ;
    echo '</a></div><!--end datetime-->' ;
    
    $html = ob_get_clean() ; 
    
    return apply_filters( 'cks_exc_comment_datetime', $html, $comment ) ;
    
}

function cks_exc_in_reply_to( $comment, $pre_irt ) {
    
    $commentparent = get_comment( $comment->comment_parent );
    
    if ( $comment->comment_parent ) { 
    
        $commentparentpage = get_page_of_comment( $commentparent );
        $comment_par_link = htmlspecialchars( get_comment_link( 
                        $commentparent, 
                        array( 'page' => $commentparentpage ) ) 
                        );
        $comment_par_author = $commentparent->comment_author ;
    
        ob_start() ;
    
        echo '<div class="comment-irt cks_exc-comment-irt"> ' ;
        
        $irt = '<span class="cks_exc-pre-irt">' . $pre_irt .'</span><a href="' 
                .  $comment_par_link . '">'  
                .  $comment_par_author . '</a>' ;
        
        echo apply_filters( 'cks_exc_irt_text', $irt ) ;
        
        echo '</div>' ; 
        
        echo '<!--end in reply to-->' ;
    
        $html = ob_get_clean() ; 
        
        return apply_filters( 'cks_exc_in_reply_to', $html, $comment ) ;
        
    } else {
        
        return '<!--no in reply to-->' ;
        
    }
    
}

function cks_exc_post_title( $comment, $pre_title ) { 
    
    $post_id = $comment->comment_post_ID;
    
    ?>
    
    <div class="cks_exc-post-title">
        <span class="cks_exc-pre-title"><?php 
        echo  $pre_title ; ?></span><a href="<?php 
        echo get_permalink( $post_id ) ; ?>"><?php
        echo apply_filters( 'cks_exc_post_title',                            
        get_the_title( $post_id ), $comment ) ; ?></a>
    </div><!--end title-->
    
    <?php
    
}

function cks_exc_comment_author( $comment, $gravatar_size ) {
    
    ?>

    <div class="comment-author cks_exc-comment-author">                    
                        
        <?php echo $gravatar_size !== 'none' ? 
            get_avatar( $comment->comment_author_email, $gravatar_size ) : '' ;
        ?>

        <span class="cks_exc-comment-author-name">
            
            <?php echo apply_filters( 'cks_exc_archive_author_link',
                get_comment_author_link( $comment->comment_ID ), $comment) ; ?>
            
        </span>

    </div><!--end author-->

<?php

}

/** 
 * ADD CK'S PLUGINS CREDIT
 * produces image-link styled to appear flush left, buttom
 */
function cks_cfix_add_credit( $show_credit ) {
    
    $output = '' ;
    
    if ( $show_credit ) {
        
        $output .= '<div class="cks-plugins-credit">' ;

        $output .= '<a href="http://ckmacleod.com/wordpress-plugins/" '
                . 'title="CKs WP Plugins">' ;

        $output .= '<img src="' .  plugin_dir_url( __FILE__ ) 
                . 'images/cks_wp_plugins_80x16.jpg" alt="CK\'s WP Plugins">'
                . '</a>' ;

        $output .= '</div> ' ;
    
    }
    
    return $output ;
    
}

/**
 * PROVISIONAL FOR FUTURE ACTIVATION 
 * @param type $comment
 *
function show_commenter_archives( $comment ) {
    
    $cid= $comment->comment_ID;
    
    echo '<div class="commenter-archives">' ;
    echo '<a class="cthread_open" title="View Comments on This Thread by ' 
    . $comment->comment_author . '" onclick="window.open( this.href, 
        \'threadwindow\',\'right=20,top=20,width=500,height=640,
        scrollbars=yes,resizable=yes,location=no,menubar=no,toolbar=no\' ); 
        return false;" href="' . esc_url( home_url( '/' ) ) 
            . 'commenter-thread?cid=' . $cid 
            . '&cthread=true" rel="nofollow"><img class="comments-thread-icon" '
            . 'src="' . get_stylesheet_directory_uri() 
            . '/imgs/comments_40px.png" alt="Comments this thread"  /></a>'; 
    echo '<a class="c-archive-open" title="Commenter Archive for ' 
    . $comment->comment_author . '" href="' . esc_url( home_url( '/' ) ) 
            . 'commenter-archive?cid=' . $cid 
            . '" rel="nofollow" target="_blank" /><img class="'
            . 'comment-archive-icon" src="' . get_stylesheet_directory_uri()
            . '/imgs/comment_archive_40px.png" alt="Commenter Archive"  /></a>'; 
    echo '</div>' ;

 }
 
 */
