<?php
/*
 * Plugin Name: Extraordinary Comments
 * Plugin URI: http://ckmacleod.com/wordpress-plugins/extraordinary-comments
 * Description: Highlight (or bury) extraordinary comments, and display them in a widget, archive, or both. (Extends "Featured Comments.")
 * Version: 1.0
 * Author: CK MacLeod
 * Author URI: http://ckmacleod.com/
 * License: GPL3, http://www.gnu.org/licenses/gpl.txt
 * Text Domain: cks_exc
 * Domain Path: /languages
 * 
*/

defined( 'ABSPATH' ) or die( 'Plugin file cannot be accessed directly.' ) ;

if ( ! defined( 'CKS_EXC_VERSION' ) ) {
    
    define( 'CKS_EXC_VERSION', '1.0' ) ;
    
}

final class Extraordinary_Comments {

    /** Singleton *************************************************************/

    /**
     * @var Extraordinary_Comments
     */
    private static $instance;

    private static $actions;

    /**
     * Main Extraordinary_Comments Instance
     *
     * Insures that only one instance of Extraordinary_Comments exists in memory at any one
     * time. Also prevents needing to define globals all over the place.
     *
     * @since v1.0
     * @staticvar array $instance
     * @see pw_extraordinary_comments_load()
     * @return The one true Extraordinary_Comments
     */
    public static function instance() {

        if ( ! isset( self::$instance ) ) {
            
            self::$instance = new Extraordinary_Comments;
            self::$instance->includes();
            self::$instance->init();
            do_action( 'extraordinary_comments_loaded' );
            
        }
        
        return self::$instance;
        
    }

    private function includes() {
        
        include_once( dirname( __FILE__ ) 
                . '/exc-widget.php' ) ;
        include_once( dirname( __FILE__ ) 
                . '/exc-archive.php' ) ;
        
    }

    /** Filters & Actions **/
    function init() {

        self::$actions = array(
                'feature'   => __( 'Feature',   'cks_exc' ),
                'unfeature' => __( 'Unfeature', 'cks_exc' ),
                'bury'      => __( 'Bury',      'cks_exc' ),
                'unbury'    => __( 'Unbury',    'cks_exc' ),
        );

        /* Backend */
        add_action( 'edit_comment',             
                array( $this, 'save_meta_box_postdata'  ) ) ;
        add_action( 'admin_menu',               
                array( $this, 'add_meta_box'            ) ) ;
        add_action( 'wp_ajax_feature_comments', 
                array( $this, 'ajax'                    ) ) ;
        add_filter( 'comment_text',             
                array( $this, 'comment_text'            ), 10, 3 ) ; 
        add_filter( 'comment_row_actions',      
                array( $this, 'comment_row_actions'     ) ) ;
        add_action( 'wp_print_scripts',         
                array( $this, 'print_scripts'           ) ) ;
        add_action( 'admin_print_scripts',      
                array( $this, 'print_scripts'           ) ) ;
        add_action( 'wp_print_styles',          
                array( $this, 'print_styles'            ) ) ;
        add_action( 'admin_print_styles',       
                array( $this, 'admin_print_styles'      ) ) ;
        add_action( 'admin_init',       array( &$this, 
            'save_cks_exc_stylesheet_options'           ) ) ;
        add_action( 'admin_notices', 
                array( $this, 'css_add__success'        ) ) ;
        add_action( 'admin_init',       
                array( &$this, 'admin_init'             ) ) ;
        add_action( 'admin_menu',       
                array( &$this, 'add_menu'               ) ) ;
        add_action( 'plugins_loaded',   
                array( &$this, 'check_version'          ) ) ;
        add_action( 'wp_head',          
                array( &$this, 'page_header_output'     ) ) ;
        add_action( 'init',             
                array( &$this, 'load_translation_file'  ) ) ;

        /* Frontend */
        add_filter( 'comment_class',            
                array( $this, 'comment_class'           ) ) ;
        
        /* installation/uinstallation */
        // --- Hooks ---------------------------------------------------------//
        
        register_activation_hook( __FILE__, 
                array( &$this, 'install' ) );
    
    }

   /**
    * SET DEFAULT OPTIONS ON FIRST INSTALLATION
    */
    static function install() {
            
           self::$instance->set_default_options() ;
        
    }
    
     public function admin_init() {
        // Set up the settings for this plugin
        $this->init_settings() ;
        
    } // END public static function activate

    /**
     * Initialize some custom settings
     */     
    public function init_settings()
    {
        
        register_setting( 'cks_exc', 'cks_exc_version' ) ;
        register_setting( 'cks_exc', 'cks_exc_use_plugin_styles' ) ;

        
    } // END public function init_custom_settings()
    
    /**
     * add an Options Page
     */     
    public function add_menu() {
        
        add_options_page( 
                'Extraordinary Comments', 
                'Extraordinary Comments', 
                'manage_options', 
                'cks_exc', 
                array(&$this, 'plugin_settings_page' 
                    ) );
        
    } // END public function add_menu()

    /**
     * Menu Callback
     */     
    public function plugin_settings_page() {
        
        if ( ! current_user_can( 'manage_options' ) ) {
                wp_die(__( 'You do not have sufficient permissions '
                        . 'to access this page.', 'cks_exc' ) );
        }

        // Render the settings template
        include_once( dirname( __FILE__ ) . '/exc-settings.php' ) ;
        } // END public function plugin_settings_page()
        
    //update current version if necessary
    public function check_version() {    
        
        if ( CKS_EXC_VERSION !== get_option( 'cks_exc_version') ) {
        
        update_option( 'cks_exc_version', CKS_EXC_VERSION ) ;
        
        }
        
    }   
    
    static function set_default_options() {
                
        update_option( 'cks_exc_version', CKS_EXC_VERSION ) ;
        
            //set extra stylesheet option/location separately - 
            //makes accessing/saving more convenient
        $stylesheet_location = plugin_dir_path( __FILE__ ) 
                . 'css/exc_add_css.css' ;
        $stylesheet = file_get_contents( $stylesheet_location ) ;
        update_option( 'cks_exc_style', $stylesheet ) ;
        update_option( 'cks_exc_use_plugin_styles', '' ) ;
        
    }
    
    function page_header_output() { 

        if ( get_option( 'cks_exc_use_plugin_styles' ) ) {
        
            ?>

            <style type='text/css'>

                <?php

                    $option = get_option( 'cks_exc_style' ) ;

                    echo $option ;

                ?>

            </style>
    
            <?php 
            
        }
        
    }

    /**
     *  ADD CSS 
     */
    function save_cks_exc_stylesheet_options() {

        add_action( 'admin_post_save_cks_exc_stylesheet_options', 
                'process_cks_exc_stylesheet_options' ) ;

    }

    function load_translation_file() {
    
    // relative path to WP_PLUGIN_DIR where the translation files will sit:
    $plugin_path = plugin_basename( dirname( __FILE__ ) . '/languages' ) ;
    load_plugin_textdomain( 'cks_exc', '', $plugin_path ) ;
    
    }

    // Scripts
    function print_scripts() {

        if ( current_user_can( 'moderate_comments' ) ) {
            
            wp_enqueue_script( 'extraordinary_comments', 
                    plugin_dir_url( __FILE__ ) 
                    . 'extraordinary-comments.js', array( 'jquery' ), 
                    filemtime( dirname( __FILE__ ) 
                            . '/extraordinary-comments.js' ) );
            
            wp_localize_script( 'extraordinary_comments', 
                    'extraordinary_comments', array(
                        'ajax_url' => admin_url( 'admin-ajax.php' )
                ) );
            
        }
        
    }

    // Styles for admin menu
    function print_styles() {
        
        if ( current_user_can( 'moderate_comments' ) ) {
            
        ?>
            <style>
                .feature-comments.unfeature, .feature-comments.unbury {display:none;}
                .feature-comments { cursor:pointer;}
                .featured.feature-comments.feature { display:none;}
                .featured.feature-comments.unfeature { display:inline;}
                .buried.feature-comments.bury { display:none;}
                .buried.feature-comments.unbury { display:inline;}
                #the-comment-list tr.featured { background-color: #dfd; }
                #the-comment-list tr.buried { opacity: 0.5; }
            </style>
        <?php

        }
        
    }

    function ajax() {

        if ( ! isset( $_POST['do'] ) ) die;

        $action = $_POST['do'];

        $actions = array_keys( self::$actions );

        if ( in_array( $action, $actions ) ) {

            $comment_id = absint( $_POST['comment_id'] );
            $comment    = get_comment( $comment_id );

            if ( ! $comment ) {
                die;
            }

            if( ! current_user_can( 'edit_comment', $comment_id ) ) {
                die;
            }

            if( ! wp_verify_nonce( 
                    $_POST['nonce'], 'extraordinary_comments' ) ) {
                
                die;
                
            }

            switch ( $action ) {

                case 'feature':
                    update_comment_meta( $comment_id, 'featured', '1' ); 
                    break;

                case 'unfeature':
                    update_comment_meta( $comment_id, 'featured', '0' );
                    break;

                case 'bury':
                    update_comment_meta( $comment_id, 'buried', '1');
                    break;

                case 'unbury':
                    update_comment_meta( $comment_id, 'buried', '0');
                    break;

    die( wp_create_nonce( 'extraordinary_comments' ) );

            }
            
        }
        
        die;
        
    }

    function comment_text( $comment_text ) { 
        
        if( is_admin() || ! current_user_can( 'moderate_comments' ) ) {
            
                return $comment_text;
                
        }

        global $comment;

        $comment_id = $comment->comment_ID;
        $data_id    = ' data-comment_id=' . $comment_id;

        $current_status = implode( ' ', self::comment_class() );
        
        $output = '<div class="feature-bury-comments">';
        
        foreach( self::$actions as $action => $label ) {
            
            $output .= "<a class='feature-comments {$current_status} "
                    . "{$action}' "
                    . "data-do='{$action}' {$data_id} data-nonce='" 
                    . wp_create_nonce( "extraordinary_comments" ) 
                    . "' title='{$label}'>{$label}</a> "
                    ; 
                
        }
                
        $output .= '</div>';

        return $comment_text . $output;
        
    }

    function comment_row_actions( $actions ) {

        global $comment, $post, $approve_nonce;

        $comment_id = $comment->comment_ID;

        $data_id = ' data-comment_id=' . $comment->comment_ID;

        $current_status = implode( ' ', self::comment_class() );

        $o = '';
        $o .= "<a data-do='unfeature' {$data_id} data-nonce='" 
            . wp_create_nonce( 'extraordinary_comments' ) 
            . "' class='feature-comments unfeature {$current_status} "
            . "dim:the-comment-list:comment-{$comment->comment_ID}:"
            . "unfeatured:e7e7d3:e7e7d3:new=unfeatured vim-u' title='" 
            . esc_attr__( 'Unfeature this comment', 'cks_exc' ) 
            . "'>" . __( 'Unfeature', 'cks_exc' ) . '</a>';
            
        $o .= "<a data-do='feature' {$data_id} data-nonce='" 
            . wp_create_nonce( 'extraordinary_comments' ) 
            . "' class='feature-comments feature {$current_status} "
            . "dim:the-comment-list:comment-{$comment->comment_ID}:"
            . "unfeatured:e7e7d3:e7e7d3:new=featured vim-a' title='" 
            . esc_attr__( 'Feature this comment', 'cks_exc' ) 
            . "'>" . __( 'Feature', 'cks_exc' ) . '</a>';
            
        $o .= ' | ';
        
        $o .= "<a data-do='unbury' {$data_id} data-nonce='" 
            . wp_create_nonce( 'extraordinary_comments' ) 
            . "' class='feature-comments unbury {$current_status} "
            . "dim:the-comment-list:comment-{$comment->comment_ID}:"
            . "unburied:e7e7d3:e7e7d3:new=unburied vim-u' title='" 
            . esc_attr__( 'Unbury this comment', 'cks_exc' ) 
            . "'>" . __( 'Unbury', 'cks_exc' ) . '</a>';
           
        $o .= "<a data-do='bury' {$data_id}  data-nonce='" 
            . wp_create_nonce( 'extraordinary_comments' ) 
            . "' class='feature-comments bury {$current_status} "
            . "dim:the-comment-list:comment-{$comment->comment_ID}:"
            . "unburied:e7e7d3:e7e7d3:new=buried vim-a' title='" 
            . esc_attr__( 'Bury this comment', 'cks_exc' ) . "'>" 
            . __( 'Bury', 'cks_exc' ) . '</a>';
            
        $o = "<span class='$current_status'>$o</span>";

        $actions['feature_comments'] = $o;

        return $actions;
        
    }

    function add_meta_box() {
        
        add_meta_box( 'comment_meta_box', 
                __( 'Extraordinary Comments', 'cks_exc' ), 
                array( $this, 'comment_meta_box' ), 'comment', 'normal' );
        
    }

    function save_meta_box_postdata( $comment_id ) {

        if ( ! wp_verify_nonce( $_POST['extraordinary_comments_nonce'], 
                plugin_basename( __FILE__ ) ) ) {
            
            return;
                
        }

        if ( !current_user_can( 'moderate_comments', $comment_id ) ) {
            
            comment_footer_die( 
                    __( 'You are not allowed to edit comments on this post.', 
                            'cks_exc' ) );
            
        }

        update_comment_meta( $comment_id, 'featured', 
                isset( $_POST['featured'] ) ? '1' : '0' );
        
        update_comment_meta( $comment_id, 'buried',   
                isset( $_POST['buried'] )   ? '1' : '0' );
}

    function comment_meta_box() {

        global $comment;
        $comment_id = $comment->comment_ID;
        
        echo '<p>';
        
        echo wp_nonce_field( plugin_basename( __FILE__ ), 
                'extraordinary_comments_nonce' );
        
        echo '<input id="featured" type="checkbox" name="featured" '
            . 'value="true"' . checked( true, 
                self::is_comment_extraordinary( $comment_id ), false ) 
            . '/>';
        
        echo ' <label for="featured">' 
            . __( "Extraordinary", 'cks_exc' ) 
            . '</label>&nbsp;';
        
        echo '<input id = "buried" type="checkbox" name="buried" value="true"' 
            . checked( true, self::is_comment_buried( $comment_id ), false ) 
            . '/>';
        
        echo ' <label for="buried">' . __( "Buried", 'cks_exc' ) 
            . '</label>';
        
        echo '</p>';
}

    function comment_class( $classes = array() ) {
        
        global $comment;

        $comment_id = $comment->comment_ID;

        if ( self::is_comment_extraordinary( $comment_id ) ) {
            
            $classes[] = 'featured';
            
        }

        if( self::is_comment_buried( $comment_id ) ) {
            
            $classes [] = 'buried';
            
        }

        return $classes;
        
    }

    private function is_comment_extraordinary( $comment_id ) {
    
        if ( '1' == get_comment_meta( $comment_id, 'featured', true ) ) {
            
            return 1;
            
        }
        
        return 0;
        
    }

    private function is_comment_buried( $comment_id ) {
        
        if( '1' == get_comment_meta( $comment_id, 'buried', true ) ) {
            
            return 1;
            
        }
        
        return 0;
        
    }
    
    function admin_print_styles() {

        wp_register_style( 
                'exc-styles', 
                plugins_url( 'css/exc-admin-styles.css'. '?v=' . 
                        CKS_EXC_VERSION, __FILE__ ) 
                );
        
        if ( isset( $_GET['page'] ) &&  $_GET['page'] === "cks_exc" )  {    
            
            wp_enqueue_style( 'exc-styles' );
            
        }
        
        wp_register_style( 
        'exc-admin-comment-styles', 
        plugins_url( 'css/exc-admin-comment-styles.css' . '?v=' . 
                CKS_EXC_VERSION, __FILE__ ) 
        );
        
        $screen = get_current_screen();       
        
        if ( $screen->base == 'edit-comments' && 
                current_user_can( 'moderate_comments' ) ) {
            
            wp_enqueue_style( 'exc-admin-comment-styles' );
            
        }
   
    }
    
    /**
    * COMPLETION MESSAGES FOR ADD CSS
    */
    function css_add__success() {

        $message_text_applied = ' and Applied.' ;

        $class = 'notice notice-success is-dismissible' ;

        if ( isset( $_GET['page'] ) && $_GET['page']  === 'cks_exc' 
                && isset( $_GET['message'] ) && $_GET['message'] === '1' ) {

            $message_text = __( 'CSS Saved', 'cks_exc') ;

            if ( isset( $_GET['applied'] ) && 'a' === $_GET['applied'] ) {

                $message_text .= $message_text_applied ;

            }

            printf( '<div class="%1$s"><p><strong>%2$s</strong></p></div>', 
                    $class, $message_text );

        } elseif ( isset( $_GET['page'] ) && $_GET['page'] === 'cks_exc' && 
                isset( $_GET['message'] ) && $_GET['message'] === '2' ) { 

            $message_text = __( 'CSS Reset to Original Styles', 'cks_exc') ;

            if ( isset( $_GET['applied'] ) && 'a' === $_GET['applied'] ) {

                $message_text .= $message_text_applied ;

            }

            printf( '<div class="%1$s"><p><strong>%2$s</strong></p></div>', 
                    $class, $message_text );

        }

    }
   
}

function wp_extraordinary_comments_load() {
    
    return Extraordinary_Comments::instance();
    
}

// load Extraordinary Comments
wp_extraordinary_comments_load();

/*ENQUEUE STYLESHEET */
add_action('wp_enqueue_scripts', 'extraordinary_comments_r_stylesheet');

function extraordinary_comments_r_stylesheet() {
    
    wp_enqueue_style(
            'extraordinarycrstyle', plugins_url('css/exc-style.css' 
            . '?v=' 
            . CKS_EXC_VERSION, __FILE__)
            );
    
}

// Add a link to the settings page onto the plugin page
if ( isset( $wp_plugin_template ) ) {
    
    // Add the settings link to the plugins page
    function cks_exc_plugin_settings_link( $links ) { 
        
        $settings_link = 
                '<a href="options-general.php?page=cks_exc">Settings</a>'; 
        
        array_unshift( $links, $settings_link ); 
        
        return $links; 
        
    }

    $plugin = plugin_basename( __FILE__ ); 
    
    add_filter( "plugin_action_links_$plugin", 'cks_exc_plugin_settings_link' );
    
}

function process_cks_exc_stylesheet_options() {
    
    $applied = '' ;
    
    // Check that user has proper security level
    if ( 
            ! current_user_can( 'manage_options' ) || 
            ! wp_verify_nonce( $_POST['stylesheet_nonce'], 'cks_exc_stylesheet')   
        ) {
        
        wp_die( 'Not allowed' ) ;
            
    }

    // Retrieve original plugin options array
    $option = get_option( 'cks_exc_style' ) ;

    if ( isset( $_POST['resetstyle'] ) ) {
        
        $stylesheet_location = plugin_dir_path( __FILE__ ) 
                . 'css/exc_add_css.css' ;
        
        $option = file_get_contents( $stylesheet_location ) ;

        $message = 2;
        
    } elseif ( isset( $_POST['layout'] ) ) {

        $option = $_POST['cks_exc_style'];

        $message = 1;

    }
    
    if ( isset( $_POST['cks_exc_use_plugin_styles']) ) {
        
        $use_styles = $_POST['cks_exc_use_plugin_styles'] ;
        
        $applied = 'a' ;
        
    } else {
        
        $use_styles = 0 ;
        
    }
    
    update_option( 'cks_exc_style', $option ) ;
    update_option ( 'cks_exc_use_plugin_styles', $use_styles ) ;

    // Store updated option to database

    // Redirect the page to the configuration form that was
    // processed
    wp_safe_redirect( 
            
        add_query_arg( 
            array( 
                
                'page' => 'cks_exc', 
                'message' => $message,
                'applied' => $applied,
            ), 
            admin_url( 'options-general.php' ) 
        ) 
            
    ) ;
    
    exit() ;
    
}

/**
 * CREATE EXCERPTS FOR WIDGET OR ARCHIVE
 * @param object $comment
 * @param int $excerpt_length
 * @param string $continued_label
 * @return string
 */
function cks_exc_get_exc_comment_text( 
          $comment, $excerpt_length, $continued_label ) {
        
    $comment_text = $comment->comment_content;
    $comment_text_stripped = strip_tags( $comment_text ) ;
    $words = explode( ' ', $comment_text_stripped, $excerpt_length + 1 ) ;

    if (count( $words) > $excerpt_length ) {

        array_pop( $words ) ;

        $new_comment_text = wpautop( implode( ' ', $words ) 
                        . ' <a class="cks_exc-link-to-comment" href="' 
                        . get_comment_link( $comment ) . '">' 
                        . $continued_label 
                        . '</a>' ) ;

    } else {

        $new_comment_text = wpautop( $comment_text ) ; 

    }	

    return apply_filters( 'cks_exc_comment_text', $new_comment_text ) ;
        
}


