<?php
/**
 * Plugin Name: Image Fallbacks
 * Plugin URI: http://ckmacleod.com/category-featured-images-extended
 * Description: Comprehensive fallback options, re-extends CFI
 * Version:0.91
 * Author: CK MacLeod
 * Author: URI: http://ckmacleod.com
 * License: GPL3
 * Text Domain: cks_fatf
 * Domain Path: /languages
 * NOTES: NEEDS YOAST VS EXCL CATS FOR MAIN FUNCTION (SEE CAT FEAT IMAGE EXT)
 */

defined( 'ABSPATH' ) or die( 'Plugin file cannot be accessed directly.' ) ;

if ( ! defined( 'CKS_FATF_VERSION' ) ) {
    
    define( 'CKS_FATF_VERSION', '0.91' ) ;
    
}

include_once( ABSPATH . 'wp-admin/includes/plugin.php' ); 

class featured_thumbnail_fallbacks {
    
    function __construct() {
        
    // --- CONDITIONAL Actions---------------------------------------------------- //    
       
        $tax_r = get_option('cks_fatf_custom_tax') ;
        
        if ( is_array( $tax_r ) ) { 
        
            foreach( $tax_r as $tax_name ) {

                add_action( $tax_name . '_edit_form', 
                                            array( &$this, 'taxonomy_edit_form' ), 10, 2 );
                add_action( 'edited_' .  $tax_name,
                                            array( &$this, 'edited_taxonomy' ) );

           }
       
       }
       
       $always_assign = get_option( 'cks_fatf_always_assign' ) ;
       
       if ( $always_assign ) {
           
           add_action( 'wp_insert_post' , array( &$this, 'assign_featured_image' ), 10, 2 ) ;
           
       }
            
        
    // --- Actions ---------------------------------------------------------- //
        add_action( 'admin_print_scripts', 
                                        array( &$this, 'admin_print_scripts' ) 
                );
        add_action( 'admin_print_styles', 
                                        array( &$this, 'admin_print_styles' ) );
        add_action( 'admin_init',       array( &$this, 'admin_init' ) );
        
        add_action( 'admin_init', array( &$this, 'cks_fatf_check_assign' ) ) ;
        //add_action( 'admin_notices', array( &$this, 'cks_fatf_assign__success' ) ) ;
        add_action( 'init',       array( &$this, 'set_global_fallback' ) );
        add_action( 'admin_menu',       array( &$this, 'add_menu' ) );
        add_action( 'plugins_loaded',   array( &$this, 'check_version' ) ) ;
        add_action( 'init',             array( &$this, 'load_translation_file' ) 
                ) ;
        add_action( 'wp_ajax_delete_global_fb', array( &$this, 'delete_global_fb') ) ;
        add_action( 'wp_ajax_delete_cat_fb', array( &$this, 'delete_cat_fb') ) ;

    // --- Filters ---------------------------------------------------------- //
        add_filter( 'get_post_metadata', 
                array( &$this, 'get_post_metadata' ), 10, 4 );

    // --- Shortcodes ------------------------------------------------------- //
        add_shortcode( 'fatf_featured_image', 
                array( &$this, 'show_featured_image' ) );
        add_shortcode( 'fatf_featured_image_url', 
                array( &$this, 'get_featured_image_url' ) );

    // --- Hooks ------------------------------------------------------------ //
        
        //fatf
        register_activation_hook( __FILE__, 
                array( 'featured_thumbnail_fallbacks', 'install' ) );
    }
    
    function delete_global_fb() {
        
        $option = get_option( 'cks_fatf_global_fallback' ) ;
        $msg = 'Image [' . $_POST['attID'] . '] removed' ;
        $remove = $_POST['attID'] ;
        if (($key = array_search( $remove, $option )) !== false ) {
            unset($option[$key]) ;
        }
        
        $option = array_values( $option ) ;
        update_option( 'cks_fatf_global_fallback', array_filter( $option ) ) ;
    }
    
    function delete_cat_fb() {
        
        $option = get_option( 'cks_fatf_featured_images' ) ;
        $msg = 'Image [' . $_POST['attID'] . '] removed' ;
        $remove = $_POST['attID'] ;
        $cat_id = $_POST['catID'] ;
        if (($key = array_search( $remove, $option[$cat_id] )) !== false ) {
            unset($option[$cat_id][$key]) ;
        }
        
        update_option( 'cks_fatf_featured_images', array_filter($option) )  ;
    }

    //fatf
    public function admin_init() {
        // Set up the settings for this plugin
        $this->init_settings() ;
        
    } // END public static function activate

    /**
     * Initialize some custom settings
     */     
    public function init_settings()
    {
        
        // register the settings for this plugin
        register_setting( 'cks_fatf', 'cks_fatf_exclude_category', 
                'esc_html' ) ;
        register_setting( 'cks_fatf', ' cks_fatf_exclude_if_categories', 
                'esc_html' ) ;
        register_setting( 'cks_fatf', 'cks_fatf_version' ) ;
        register_setting( 'cks_fatf', 'cks_fatf_use_post_image', 'absint' ) ;
        register_setting( 'cks_fatf', 'cks_fatf_excluded_last_resort', 'absint' ) ;
        register_setting( 'cks_fatf', 'cks_fatf_use_yoast_primary', 'absint' ) ;
        register_setting( 'cks_fatf', 'cks_fatf_always_assign', 'absint' );
        register_setting( 'cks_fatf', 'cks_fatf_ass_taxes', 'esc_html' );
        
    } // END public function init_custom_settings()
    
    /**
     * add an Options Page
     */     
    public function add_menu() {
        
        add_options_page( 
                'Image Fallbacks', 
                'Image Fallbacks', 
                'manage_options', 
                'cks_fatf', 
                array(&$this, 'plugin_settings_page' 
                    ) );
        
    } // END public function add_menu()

    /**
     * Menu Callback
     */     
    public function plugin_settings_page() {
        
        if ( ! current_user_can( 'manage_options' ) ) {
                wp_die(__( 'You do not have sufficient permissions '
                        . 'to access this page.', 'cks_fatf' ) );
        }

        // Render the settings template
        include_once( dirname( __FILE__ ) . '/settings.php' ) ;
        } // END public function plugin_settings_page()
        
    //update current version if necessary
    public function check_version() {    
        
        if ( CKS_FATF_VERSION !== get_option( 'cks_fatf_version') ) {
        
        update_option( 'cks_fatf_version', CKS_FATF_VERSION ) ;
        
        }
        
    }   
    
    static function set_default_options() {

        add_option( 'cks_fatf_use_post_image', 1 ) ;
        add_option( 'cks_fatf_always_assign', 0 ) ;
        add_option( 'cks_fatf_use_yoast_primary', 1 );
        add_option( 'cks_fatf_exclude_category', '' ) ;
        add_option( 'cks_fatf_exclude_if_categories', '' ) ;
        add_option( 'cks_fatf_excluded_last_resort', 1 ) ;
        add_option( 'cks_fatf_featured_images', array() ) ;
        add_option( 'cks_fatf_global_fallback', array() ) ;
        
        //get_taxonomies fails if accessed directly for actions, so set return as option
        //http://wordpress.stackexchange.com/questions/250631/unexpected-results-from-get-taxonomies-and-taxonomy-edit-form-and-related-h
        $tax_r = get_taxonomies() ;
        add_option( 'cks_fatf_custom_tax', $tax_r ) ;
        add_option( 'cks_fatf_ass_taxes', '' ) ;
        update_option( 'cks_fatf_version', CKS_FATF_VERSION ) ;
        
    }

   /**
    * CLEAN UP AFTER YOURSELF
    */
    static function uninstall() {
       
        delete_option( 'cks_fatf_exclude_category' ) ;
        delete_option( 'cks_fatf_exclude_if_categories' ) ;
        delete_option( 'cks_fatf_excluded_last_resort' ) ;
        delete_option( 'cks_fatf_featured_images') ;
        delete_option( 'cks_fatf_version' ) ;
        delete_option( 'cks_fatf_always_assign' ) ;
        delete_option( 'cks_fatf_use_yoast_primary' ) ;
        delete_option( 'cks_fatf_use_post_image' ) ;
        delete_option( 'cks_fatf_use_random' ) ;
        delete_option( 'cks_fatf_global_fallback' ) ;
        delete_option( 'cks_fatf_ass_taxes' ) ;
        delete_option( 'cks_fatf_custom_tax' ) ;
                
   }

   /**
    * UPGRADE FROM CFI FEATURED IMAGES, UPDATE OPTIONS FROM BETA VERSIONS
    * ADD FOR MIGRATION FROM CFIX
    */
    static function install() {
        
        $old_cfi_images = $old_cfix_images = $images = $new_array = $new_new_array = array();

        //existing cfi_featured_images
        if ( get_option( 'cfi_featured_images' ) ) {

            $old_cfi_images = get_option( 'cfi_featured_images' ) ; 

        }
        
        //existing cfix images
        if ( get_option( 'cks_cfix_featured_images' ) ) {
        
            $old_cfix_images = get_option( 'cks_cfix_featured_images' ) ; 

        }
        
        //combine all old images in new array format
        $old_images = array_unique( $old_cfi_images + $old_cfix_images ) ; 

        foreach ( $old_images as $old_key => $old_value ) {

            $new_value = array( $old_value ) ;
            $new_array[$old_key] = $new_value  ;

        }
        
        //existing fatf images
        $images = get_option( 'cks_fatf_featured_images' ) ;
        
        //new array
        if ( $images && $new_array ) {
            
            $shared_ks = array_intersect_key( $new_array, $images ) ; 

            foreach ( $shared_ks as $shared_k => $shared_v ) {
                $new_array_combo = array_unique( 
                    array_merge( 
                            $new_array[$shared_k], $images[$shared_k] 
                    ) 
                ) ;
                
                $images[$shared_k] = $new_array_combo ;
            }
            
            $new_new_array = $images + $new_array ;
        
        } else {
            
            $new_new_array = $new_array ;
                
        }
        
        if ( $new_new_array ) {
        
            update_option( 'cks_fatf_featured_images', $new_new_array ) ;
            
        }
        
        if ( ! get_option( 'cks_fatf_version ') ) {
            
            featured_thumbnail_fallbacks::set_default_options() ;
            
       }
        
        register_uninstall_hook( __FILE__, 
                array( 'featured_thumbnail_fallbacks', 'uninstall' ) );
        
    }
    
    function cks_fatf_check_assign() {
        
        $assign = filter_input( INPUT_POST, '_assign', FILTER_SANITIZE_STRING ) ;
        
        $tax_string = filter_input( INPUT_POST, 'tax_string', FILTER_SANITIZE_STRING ) ;

        if ( $assign ) {

            $nonce = filter_input( INPUT_POST, '_fatf_assign_nonce', FILTER_SANITIZE_STRING ) ;

            if ( wp_verify_nonce( $nonce, 'cks_fatf_assign' ) ) {
                
                $args = array( 'posts_per_page' => -1 ) ;
                
                if ( $tax_string ) {
                    
                    update_option( 'cks_fatf_ass_taxes', $tax_string ) ;
                
                    $names_array = explode(',', $tax_string );

                    $tax_r = get_option('cks_fatf_custom_tax') ;

                    foreach ( $tax_r as $tax_name ) {

                        $tax_subquery[] = array(

                            'taxonomy'  => $tax_name,
                            'field'     => 'name',
                            'terms'     => $names_array,


                        );

                    }

                    $tax_subquery['relation'] = 'OR' ;

                    $args['tax_query'] = array( $tax_subquery ) ;
                    
                }

                if ( 'assign' === $assign ) {

                    $posts = get_posts( $args ) ;
                    
                    $i = 0 ;
                    
                    foreach ( $posts as $each ) { 
                        
                        $post_ID = $each->ID ;
                        
                        if ( ! get_post_thumbnail_id( $post_ID ) ) {
                            
                            $ass_thumb = featured_thumbnail_fallbacks::get_image( $post_ID );

                            update_post_meta( $post_ID, '_thumbnail_id', $ass_thumb ) ;

                            update_post_meta( $post_ID, '_assigned_thumb_id', $ass_thumb ) ;

                            update_post_meta( $post_ID, '_assigned_thumb', 'assigned' ) ;

                            $i++;
                                
                        }
                        
                    }
                    
                    $message_text = $i . ' Featured Images Assigned' ;

                    $class = 'notice notice-success is-dismissible';

                    printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message_text );
                                        
                }

                if ( 'delete' === $assign  ) {

                    $posts = get_posts( $args ) ;
                    
                    $i = 0 ;
                    
                    foreach ( $posts as $each ) { 
                        
                        $post_ID = $each->ID ;
                            
                        $assigned = get_post_meta( $post_ID, '_assigned_thumb', true ) ;
                        $assigned_thumb_id = get_post_meta( $post_ID, '_assigned_thumb_id', true ) ;
                        $thumb_id = get_post_thumbnail_id( $post_ID, '_thumbnail_id' ) ;
                        
                        if ( $assigned ) {
                            
                            delete_post_meta( $post_ID, '_assigned_thumb' ) ;
                     
                        
                            if ( $assigned_thumb_id === $thumb_id ) {
                                
                                delete_post_meta( $post_ID, '_thumbnail_id' ) ;
                        
                            }
                            
                            
                            delete_post_meta( $post_ID, '_assigned_thumb_id' ) ;
                            
                            $i++;
                        
                        }
                        
                    }
                    
                    $message_text = $i . ' Image Assignments Removed' ;

                    $class = 'notice notice-success is-dismissible';

                    printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message_text );
                    
                }
                
                if ( 'delete_and_assign' === $assign ) {
                    
                    $posts = get_posts( $args ) ;
                    
                    //need check otherwise will/have deleted ALL thumbnails!
                    
                    $i = 0 ;
                    
                    foreach ( $posts as $each ) { 
                        
                        $post_ID = $each->ID ;
                            
                        $assigned = get_post_meta( $post_ID, '_assigned_thumb', true ) ;
                        $assigned_thumb_id = get_post_meta( $post_ID, '_assigned_thumb_id', true ) ;
                        $thumb_id = get_post_thumbnail_id( $post_ID, '_thumbnail_id' ) ;
                        
                        if ( $assigned ) {
                            
                            delete_post_meta( $post_ID, '_assigned_thumb' ) ;
                     
                        
                            if ( $assigned_thumb_id === $thumb_id ) {
                                
                                delete_post_meta( $post_ID, '_thumbnail_id' ) ;
                        
                            }
                            
                            
                            delete_post_meta( $post_ID, '_assigned_thumb_id' ) ;
                            
                            $i++;
                        
                        }
                        
                    }

                    $posts = get_posts( $args ) ;
                    
                    $j = 0 ;
                    
                    foreach ( $posts as $each ) { 
                        
                        $post_ID = $each->ID ;
                        
                        if ( ! get_post_thumbnail_id( $post_ID ) ) {
                            
                                $ass_thumb = featured_thumbnail_fallbacks::get_image( $post_ID );
                                
                                update_post_meta( $post_ID, '_thumbnail_id', $ass_thumb ) ;

                                update_post_meta( $post_ID, '_assigned_thumb_id', $ass_thumb ) ;

                                update_post_meta( $post_ID, '_assigned_thumb', 'assigned' ) ;
                                
                                $j++;
                                
                        }
                        
                    }
                    
                    $message_text = $i . ' Image Assignments Removed<br>' . $j . ' Featured Images Assigned' ;

                    $class = 'notice notice-success is-dismissible';

                    printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message_text );   

                } 
                
            } else {

                print 'Sorry: No nonce, no access.' ;
                exit;
                
            }

        }
        
    }

    /**
     * Admin Notice for Reset Options
     */


    function cks_fatf_assign__success() {

        $assign = filter_input( INPUT_POST, '_assign', FILTER_SANITIZE_STRING ) ;
        $nonce = filter_input( INPUT_POST, '_fatf_assign_nonce', FILTER_SANITIZE_STRING ) ;

        if ( $assign && wp_verify_nonce( $nonce, 'cks_fatf_assign' ) ) {

            $message_text = '' ;

            if ( 'assign' === $assign )             { $message_text = __( 'Featured Images Assigned', 'cks_fatf' ) ; }
            if ( 'delete' === $assign )             { $message_text = __( 'Image Assignments Removed', 'cks_fatf' ) ; }
            if ( 'delete_and_assign' === $assign )  { $message_text = __( 'Legacy Assignments Removed, New Images Assigned', 'cks_fatf' ) ; }

            $class = 'notice notice-success is-dismissible';

            printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message_text );

        }

    }

    function admin_print_scripts() {

        wp_enqueue_media();
        
        wp_register_script( 
                'fatf-media-upload', 
                plugins_url( 'js/fatf-media-upload.js', 
                        __FILE__ ), 
                array( 'jquery' ),
                CKS_FATF_VERSION
                );
    
        // Localize the script with new data
        $media_trans_array = array(
            'title'  => __( 'Choose Image(s)', 'cks_fatf' ),
            'button' => __( 'Choose Image(s)', 'cks_fatf' ),
        );
        
        wp_localize_script( 'fatf-media-upload', 'button_text', 
                $media_trans_array );
        
        
        
        wp_register_script( 
                'fatf-select-cat-image', 
                plugins_url( 'js/fatf-select-cat-image.js',
                        __FILE__ ), 
                array( 'jquery' ),
                CKS_FATF_VERSION
                );
        
        // Localize the script with new data
        $settings_trans_array = array(
            
            'save_changes'  => __( '"Save Changes" to make', 'cks_fatf' ),
            'new_fallback'  => __( 'your new Global Fallback.', 'cks_fatf' ),
            'or_cancel'     => __( 'or CANCEL', 'cks_fatf' ),
            'ajaxurl'       => admin_url( 'admin-ajax.php' )
            
        );
        
        wp_localize_script( 'fatf-select-cat-image', 'select_cat_strings', 
                $settings_trans_array );
        
        if ( isset( $_GET['page'] ) && $_GET['page'] == 'cks_fatf' ) {    
            
            wp_enqueue_script( 'fatf-select-cat-image' );
            wp_enqueue_script( 'fatf-media-upload' );
            
        }
        
        $screen = get_current_screen();
    
        if ( $screen->base == 'term' )  {    
            
            wp_enqueue_script( 'fatf-select-cat-image' );
            wp_enqueue_script( 'fatf-media-upload' );
            
        }

    }

    function admin_print_styles() {

        wp_register_style( 
                'fatf-styles', 
                plugins_url( 'fatf-styles.css'. '?v=' . 
                        CKS_FATF_VERSION, __FILE__ ) 
                );
        
        $screen = get_current_screen();
        
        if ( (isset( $_GET['page'] ) ) && ( $_GET['page'] === "cks_fatf" ) || 
                $screen->base == 'term' )  {    
            
            wp_enqueue_style( 'fatf-styles' );
            
        }

   }

   /**
    * UPLOAD A FEATURED IMAGE FOR A TAG, CATEGORY, OR CUSTOM TAXONOMY
    * 
    */
   
   /**
    * CATEGORY EDIT FOM
    * @param object $tag
    * @param taxonomy slug $taxonomy
    */
   function taxonomy_edit_form( $term, $taxonomy) {
           
        //$term_name = $term->name ;
        
        $tax_label = get_taxonomy( $taxonomy )->labels->singular_name  ;
           
        $term_ID = $term->term_id ;
        $term_name = $term->name ;

        $images = get_option( 'cks_fatf_featured_images' );
        $image = '' ;
        
        if ( $images === FALSE ) {
            
            $images = array() ;
            
        }
         
        $image_arr = isset( $images[$term_ID] ) ? $images[$term_ID] : array() ;
        
        //change title, but with jQuery also changed
            
            $change_button = __( 'Add Image(s)', 'cks_fatf') ;
            
        ?>

        <table class="form-table">
             <tr class="form-field">
                 <th valign="top" scope="row">
                     <label><?php 
                     //restore "name" of taxonomy function
                     
                     _e( $tax_label .
                             ' Image(s)', 'cks_fatf' ) ; ?></label>
                 </th>
                 <td>
                     <div id="fatf-term-images">
                     <?php 
                     
                     if (isset( $image_arr )  && is_array( $image_arr ) ) :

                     foreach( $image_arr as $image ) : ?>
                     <div class="fatf-term-image">
                            <?php
                            $html = '<div class="fatf-image-select-item fatf-cat-select-item"><a '
                          . 'id="' . $image . '-' . $term_ID . '" '
                          . 'class="fatf-cat-image-link" '
                          . 'alt="' . $term_name 
                          . '" title="' . $term_name . __( ' Image', 'cks_fatf' )
                          . '" data="' . $term_name 
                          . '" href="' . wp_get_attachment_url( $image ) 
                          .'">' 
                          . wp_get_attachment_image( 
                              $image, array( 150,150 ), false, 
                                  array( 

                                      'class' => 'fatf-cat-image', 
                                      'data'  => $term_name ,
                                      'alt'   => $term_name ,
                                      'title' => $term_name . __( ' Image', 'cks_fatf' ), 

                                    ) 
                            
                            ) . '</a>' ;
                        $html .=   '<a class="remcImage" id="remcImage' . $image . '-' . $term_ID. '" name="' 
                                . $image 
                                .'" data="' . $term_ID . '" '
                                . 'href="#">' . __('x') 
                                . '</a>
                            <input type="hidden" id="att_remove-' . $image . ' name="att_remove[]" value="' 
                                .  $image . '" />
                            <input type="hidden" name="nonce" id="nonce" value="' 
                                .  wp_create_nonce( 'delete_c_attachment' ). '" />' 
                                . '</div>' ;

                    echo $html ;
                       ?>
                     </div><!--fatf-term-image-->
                    <?php endforeach; ?>
                    <?php endif ; ?>
                    </div><!--fatf-term-images-->
                    
                     <div id="fatf-cat-edit-buttons">
                     
                        <input id="fatf-featured-image" type="hidden" 
                               name="cks_fatf_featured_image" 
                               readonly="readonly" value="<?php 
                               echo $image; ?>" />
                        <input id="fatf-change-image" class="button" 
                               type="button" value="<?php 
                               echo $change_button ; ?>" />
                     
                     </div>
                     <p><?php 
                            _e( 
                             ' Click "Update" to save your selection, '
                             . 'along with any other changes.', 
                             'cks_fatf' ) ; 
                     ?></p>
                 </td>
             </tr>
        </table>

        <?php
   }
   
   /**
    * PROCESS CATEGORY IMAGE
    * @param int $term_id
    */
   function edited_taxonomy( $term_id ) {
       
        if ( isset( $_POST['cks_fatf_featured_images'] ) ) {
       
            $images = get_option( 'cks_fatf_featured_images' );
            
            if ( $images === FALSE ) {
                
                $images = array() ;
                
            }
            
            $img_arr = $_POST['cks_fatf_featured_images'] ;
            
            foreach ( $img_arr as $img_id ) {

            $images[$term_id][] = $img_id ;
            
            }
            
            $cat_name = get_term( $term_id )->name  ;
            //why is this necessary?
            $cat_id = get_term( $term_id )->term_id ;
            $tax = get_term( $term_id )->taxonomy ;

            //IS THIS IMPORTANT TO KEEP? //
//            if ( $tax !== 'category' && 
//                    get_term_by( 'name', $cat_name, 'category') && 
//                    $images[$term_id] !== NULL ) {
//                
//                $message = '
//                    
//                    <div class="notice error bad-tax-notice is-dismissible" >
//                    <p>' . __( 'You cannot add an image to a Tag '
//                    . 'of the same name as a Category.', 'cks_fatf' ) . '</p>
//            
//                    <p style="float:right"> <a href="' 
//                    . admin_url('edit-tags.php') 
//                    . '">Return to Tags</a></p></div>' ;
//            
//                wp_die( $message ) ;
//                
//            }
            
            $images[$term_id] = array_unique( $images[$term_id] ) ;
            
            update_option( 'cks_fatf_featured_images', $images );
            
        }
        
   }
   
   /**
    * PROCESS GLOBAL FALLBACK
    * from settings.php
    */
   function set_global_fallback() {
       
       //write_log( 'ADD TO GF SET!' );
       
        if ( isset($_POST['_fatf_settings_nonce']) && wp_verify_nonce( $_POST['_fatf_settings_nonce'], 'cks_fatf_settings' ) ) {
            
            if ( isset($_POST['add_to_gf']) && is_array( $_POST['add_to_gf'] ) ) {
                
                $gf_option = get_option( 'cks_fatf_global_fallback' ) ?
                                get_option( 'cks_fatf_global_fallback') : array() ;
                $feat_option = get_option( 'cks_fatf_featured_images' ) ?
                                get_option( 'cks_fatf_featured_images') : array() ;
                
                $term_array = $_POST['add_to_gf'] ;
                
                foreach ( $term_array as $term ) {
                    
                    $images = $feat_option[$term] ;
                        
                    foreach ( $images as $image ) {   
                        
                        $gf_option[] = $image ;
                        
                    }
                    
                }
                
                $gf_option = array_unique( array_filter( $gf_option ) ) ;
                        
                update_option( 'cks_fatf_global_fallback', $gf_option ) ;
                
            }
            
            if ( isset($_POST['cks_fatf_global_fallback']) && is_array( $_POST['cks_fatf_global_fallback'] ) ) {
                
                if ( function_exists( 'write_log') ) { write_log( 'ADD TO GF SET!' ); }
                
                $gf_option = get_option( 'cks_fatf_global_fallback' ) ?
                                get_option( 'cks_fatf_global_fallback') : array() ;
                
                
                $term_array = $_POST['cks_fatf_global_fallback'] ;
                
                foreach ( $term_array as $term ) { 
                        
                    $gf_option[] = $term ;

                }
                
                $gf_option = array_unique( array_filter( $gf_option ) ) ;
                        
                update_option( 'cks_fatf_global_fallback', $gf_option ) ;
                
            }

        }
        
    }
    
    /**
     * FILTERS GET_POST_METADATA
     * pre-replace _thumbnail_id or provides fallback if set
     * @param string $meta_value
     * @param int $object_id
     * @param string $meta_key
     * @param boolean $single
     * @return attachment ID
     */
    function get_post_metadata( $meta_value, $object_id, $meta_key, $single ) {

        if ( is_admin() || '_thumbnail_id' != $meta_key ) {
            
            return $meta_value;
            
        }

        $meta_type = 'post' ;
        $meta_cache = wp_cache_get( $object_id, $meta_type . '_meta' ) ;

        if ( ! $meta_cache ) {
            
            $meta_cache = update_meta_cache( $meta_type, array( $object_id ) ) ;
            $meta_cache = $meta_cache[$object_id];
       
        }

        if ( ! $meta_key ) {
            
            return $meta_cache;
            
        }

        if ( isset( $meta_cache[$meta_key]) ) {

            if ( $single ) {
                
                //defeats false thumbnail positives - removed for now (1.31)
                //to be incorporated as option in later version
              #  if ( get_children('post_parent=' . $object_id . 
              #     '&post_type=attachment&post_mime_type=image') ) {
                    
                    return maybe_unserialize( $meta_cache[$meta_key][0] );
                    
              #  }
                
            } else {

                return array_map( 'maybe_unserialize', 
                        $meta_cache[$meta_key] ) ;

            }
                
        }
        
        if ( $single  ) {
            
            return $this->get_image( $object_id ) ;
            
        }
       
   }
   
   /**
    * THE MAIN FALLBACK FUNCTION
    * @param int $object_id - post ID used to find categories, images
    */
   public static function get_image( $object_id ) {
       
       //initial variables
        $excl_cat           = 
                get_option( 'cks_fatf_exclude_category' ) ? 
                get_option( 'cks_fatf_exclude_category' ) : '' ;
        $excluded_last_resort = ! empty( 
                 get_option( 'cks_fatf_excluded_last_resort' ) ) ? 
                 get_option( 'cks_fatf_excluded_last_resort' ) : '' ;  
        $exclude_if_cats = 
                get_option( 'cks_fatf_exclude_if_categories' ) ? 
                get_option( 'cks_fatf_exclude_if_categories' ) : '' ;
        $images             =  
                get_option( 'cks_fatf_featured_images')  ?
                get_option( 'cks_fatf_featured_images') : array() ;
        $global_fallback    = 
                 get_option( 'cks_fatf_global_fallback' )  ? 
                 get_option( 'cks_fatf_global_fallback' ) : array() ;
        $global_fallback = array_unique( array_filter( $global_fallback ) ) ;
        $use_post_image      = ! empty( 
                 get_option( 'cks_fatf_use_post_image' ) ) ? 
                 get_option( 'cks_fatf_use_post_image' ) : '' ;
        $use_yoast_cat = 
                 is_plugin_active('wordpress-seo/wp-seo.php') ? 
                 get_option( 'cks_fatf_use_yoast_primary' ) : FALSE ;
        $excl_cat_ids = $excl_if_ids = array() ;
        
        $tax_names = get_taxonomies() ;

        //convert exclude category string to array of IDs
        $excl_cat_arr = explode( ',', $excl_cat ) ;

        foreach ( $excl_cat_arr as $excl_cat_name ) {
            
            foreach ( $tax_names as $tax ) {
            
                $term = get_term_by( 'name', esc_html( $excl_cat_name ), $tax ) ;
                
                if ( $term ) {
                    
                    $excl_cat_ids[] = $term->term_id ;
                    
                }
                
            }
        
        }
        
        $excl_cat_if_arr = explode( ',', $exclude_if_cats ) ;

        foreach ( $excl_cat_if_arr as $excl_cat_name ) {
            
            foreach ( $tax_names as $tax ) {
            
                $term = get_term_by( 'name', esc_html( $excl_cat_name ), $tax ) ;
                
                if ( $term ) {
                    
                    $excl_if_ids[] = $term->term_id ;
                    
                }
                
            }
        
        }
        
        //look for an attached post image
        //DOES NOT USE "INTERNAL ATTACHED IMAGES" SINCE THOSE 
        //ARE INSERTED WITHOUT UPDATING ATTACHMENTS
        //ALSO DOES NOT TRY TO USE EXTERNAL HOSTED IMAGES
        if ( $use_post_image ) {

            $files = get_children('post_parent=' . $object_id . 
                '&post_type=attachment&post_mime_type=image&order=desc');

            if ( $files ) {

                $keys = array_reverse( array_keys( $files ) ) ;

                return $keys[0] ;

            }
            
        }
        
        if ( $images ) {

        // Look for a category featured image //actually "taxonomy" image

            $terms = wp_get_post_terms( 
                    $object_id, 
                    $tax_names, 
                    array( 'fields' => 'ids' )
                    );
            
            // return if exclude category //"taxonomy" // present among post terms
            
            if ( $excl_if_ids ) {
            
                foreach ( $terms as $term ) {

                    if ( in_array( $term, $excl_if_ids ) ) {

                        return '' ;

                    }

                }
            
            }
/* GIVE TAXONOMY AND TAG IMAGE PRIORITY WOULD GO HERE */
/* COULD INSTEAD OF SEARCHING EACH SEPARATELY, COULD SUBTRACT CATS AND TAGS, SUBTRACT TAGS
 * TO CREATE SETS
 */            
            /* ADD IF PRIMARY CATEGORY AND HAS IMAGE RETURN PRIMARY CATEGORY IMAGE */
            
            // need special exception for excluded categories etc
            
            if ( $use_yoast_cat && 
                    is_plugin_active('wordpress-seo/wp-seo.php') && 
                    ( get_post_meta( $object_id, '_yoast_wpseo_primary_category', true ) ) ) {    
                         
                //write_log( get_post_meta( $object_id, '_yoast_wpseo_primary_category', true ) ) ;
                         
                $category = get_post_meta( $object_id, '_yoast_wpseo_primary_category', true ) ;
                
                if ( ! in_array( $category, $excl_cat_ids ) ) {
                
                    return $images[$category][array_rand( $images[$category], 1)] ;
                
                }
                
            }

            // Sort in reverse chronological order
            natsort( $terms ) ;
            arsort( $terms ) ;
            $categories = apply_filters( 'cks_if_post_terms', $terms ) ;

            foreach( $categories as $category ) {   

                //use image associated with category unless
                //it is on exclude list 

                if ( 
                        isset( $excl_cat_ids ) &&
                        in_array( $category, $excl_cat_ids ) ) {

                    continue ;

                }

                //use category image

                if ( isset( $images[$category] ) ) {

                    return $images[$category][array_rand( $images[$category], 1)] ;

                } 

                // Look for the parent category image
                if ( get_category( $category ) ) {

                    $cat = get_category( $category ) ;

                    if (

                        isset( $cat->parent ) && 
                        $cat->parent > 0 && 
                        isset( $images[$cat->parent] ) && 
                        ! in_array( $cat->parent, $excl_cat_ids ) 


                        ) {

                        return $images[$cat->parent][array_rand( $images[$cat->parent], 1)] ;

                    } 

                }    

            }

            //use excluded category if available instead of global fallback

            if ( $excluded_last_resort && $excl_cat ) {

                foreach( $categories as $category ) {   

                //use image associated with category unless
                //it is on exclude list 

                    if ( isset( $images[$category] ) ) {

                        return $images[$category][array_rand( $images[$category], 1)] ;

                    } 

                    if ( get_category( $category ) ) {

                        $cat = get_category( $category ) ;

                        if (

                            isset( $cat->parent ) && 
                            $cat->parent > 0 && 
                            isset( $images[$cat->parent] ) 

                            ) {

                            return $images[$cat->parent][array_rand( $images[$cat->parent], 1)] ;

                        } 

                    }    

                }

            }
            
        }
        
        if ( $global_fallback ) {
       
            $global_fallback = array_filter( $global_fallback ) ;

             return $global_fallback[array_rand( $global_fallback, 1) ] ;
             
        }
        
        return '' ;
            
           
   }
   
   
   /**
    * ALWAYS ASSIGN FEATURED IMAGES TO NEW POSTS IF NOT MANUALLY SET
    * @param int $post_ID 
    * @param object $post
    */
    function assign_featured_image( $post_ID, $post ) {
    
        $publish = ( $post->post_status === 'publish' ) ? true : false ;
        $assigned = ( get_post_meta( $post_ID, '_assigned_thumb', true ) ) ;

        if ( ! get_post_thumbnail_id( $post_ID ) && $publish ) {

            $ass_thumb = $this->get_image( $post_ID );

            update_post_meta( $post_ID, '_thumbnail_id', $ass_thumb ) ;

            update_post_meta( $post_ID, '_assigned_thumb_id', $ass_thumb ) ;

            update_post_meta( $post_ID, '_assigned_thumb', 'assigned' ) ;

        } else {

            //clean up obsolete assignments to avoid future confusion

            if ( get_post_thumbnail_id( $post_ID ) && $assigned ) {

                $assigned_ID = get_post_meta( $post_ID, '_assigned_thumb_id', true ) ;

                $thumb_ID = get_post_thumbnail_id( $post_ID ) ;

                if ( $assigned_ID !== $thumb_ID ) {

                    delete_post_meta( $post_ID, '_assigned_thumb_id' );
                    delete_post_meta( $post_ID, '_assigned' );

                }

            }
        }

    }
   
   function load_translation_file() {
    
    // relative path to WP_PLUGIN_DIR where the translation files will sit:
    $plugin_path = plugin_basename( dirname( __FILE__ ) . '/languages' ) ;
    load_plugin_textdomain( 'cks_fatf', '', $plugin_path ) ;
    
    }
 /******************* THE TAGS/SHORTCODE FUNCTIONS ***********************/   
    

    /**
     * SHOW THE FEATURED IMAGE
     * *********************************************
     * *********NEED UPDATED LOGIC******************
     * @param array $args
     * @return string
     */
    static function show_featured_image( $args ) {
        
        global $post;
        
        $images = get_option( 'cks_fatf_featured_images' ) ;
        $use_yoast_cat = is_plugin_active('wordpress-seo/wp-seo.php') ? 
                get_option( 'cks_fatf_use_yoast_primary') : FALSE ;
        
        $post_id = isset( $args['post_id'] ) ? $args['post_id'] : $post->ID ;
        $size = isset( $args['size'] ) ? $args['size'] : 'full' ;
        
        if ( isset( $args['post_id'] ) ) {
                
            $id = get_post_thumbnail_id( $post_id ) ;
            
            if ( wp_get_attachment_image_src( $id, $size ) ) { 
                
               return '<span class="fatf-featured-image">' . 
                                wp_get_attachment_image( $id, $size ) . 
                                '</span>';
            
            }
			
        }
               
        if ( isset( $args['cat_id'] ) ) {
            
            $cat_id = intval( $args['cat_id'] ) ;
            
            if ( isset( $images[$cat_id] ) ) {
				
                foreach ( $images[$cat_id] as $catarr ) {

                    if ( isset( $catarr[0] ) ) {

                        return '<span class="fatf-featured-image">' . 
                                wp_get_attachment_image( $catarr[0], $size ) . 
                                '</span>' ;

                    }
                }
            }
        }
		
	return '<span class="fatf-featured-image">' . 
              wp_get_attachment_image( featured_thumbnail_fallbacks::get_image( $post_id ), $size ) . 
             '</span>' ;
               
   }
    /**
     * GET THE FEATURED IMAGE URL
     * @param array $args
     * @return string
     */
    static function get_featured_image_url( $args ) {
        
        global $post;
        
        $images = get_option( 'cks_fatf_featured_images' ) ;
        $use_yoast_cat = is_plugin_active('wordpress-seo/wp-seo.php') ? 
                get_option( 'cks_fatf_use_yoast_primary') : FALSE ;
        
        $post_id = isset( $args['post_id'] ) ? $args['post_id'] : $post->ID ;
        $size = isset( $args['size'] ) ? $args['size'] : 'full' ;
        
        if ( isset( $args['post_id'] ) ) {
                
            $id = get_post_thumbnail_id( $post_id ) ;
            
            if ( wp_get_attachment_image_src( $id, $size ) ) { 
                
                $attachment = wp_get_attachment_image_src( $id, $size ) ;
                
                return $attachment[0]; 
            
            }
			
        }
            
        if ( isset( $args['cat_id'] ) ) {
            
            $cat_id = intval( $args['cat_id'] ) ;
        //will need to update logic for image array
            if ( isset( $images[$cat_id] ) ) {

                $attachment = wp_get_attachment_image_src( 
                        $images[$cat_id], $size 
                        ) ;

                if ( $attachment !== FALSE ) { 
                    
                    return $attachment[0];
                    
                }

            }
                
        } else if ( is_single() ) {
                
            $id = get_post_thumbnail_id() ;
            
            if ( $id ) {
                
                $attachment = wp_get_attachment_image_src( $id, $size ) ;
                
                if ( $attachment !== FALSE ) {
                    
                    return $attachment[0];
                    
                }
            
            }
            
        } else if ( is_category() ) {
            
            $categories = get_the_category() ;
            
            if ( $categories ) {
                
                $cat = NULL;
                
                if ( $use_yoast_cat ) {
            
                    $yoast_cat = get_post_meta( 
                        $object_id, '_yoast_wpseo_primary_category', true 
                        ) ? get_post_meta( 
                        $object_id, '_yoast_wpseo_primary_category', true 
                        ) : '' ;
            
                    if ( $yoast_cat && 
                            in_array( $yoast_cat, $images ) &&
                            ! in_array( $yoast_cat, $excl_cat_ids )                
                    ) {   
                        
                        $attachment = wp_get_attachment_image_src( 
                                $images[$yoast_cat], $size 
                                ) ;
                        
                        if ( $attachment !== FALSE ) {
                            
                            return $attachment[0];
                            
                        }
            
                
                    }

                }
                
                foreach( $categories as $category ) {

                    if ( isset( $images[$category->term_id] ) ) {

                        $attachment = wp_get_attachment_image_src( 
                                $images[$category->term_id], $size 
                                ) ;
                        
                        if ( $attachment !== FALSE ) {
                            
                            return $attachment[0];
                            
                        }

                    }
                    
                    if ( $cat === NULL ) $cat = $category;
                    
                }
                    
                if ( $cat !== NULL ) {
                                
                    $parent = intval( $cat->parent ) ;
                    
                    if ( $parent > 0 && isset( $images[$parent] ) ) {
                                        
                        $attachment = wp_get_attachment_image_src( 
                                $images[$parent], $size 
                                ) ;
                        
                        if ( $attachment !== FALSE ) {
                            
                            return $attachment[0];
                            
                        }
                        
                    }
                    
                }
                
            }
            
        }

        return '' ;

    }
   
    /**
    * CONVERT INCLUDE/EXCLUDE CATEGORY NAME STRING 
    * TO ARRAY OF CATEGORIES AND CHILDREN
    * @param string $cat_string
    * @return array
    */
    function get_tax_ids( $tax_string ) {

        $arr = explode( ',', $tax_string ) ;
        
        $tax_names = get_taxonomies() ;

        foreach ( $arr as $name ) {
            
            foreach ( $tax_names as $tax ) {
            
                $term = get_term_by( 'name', esc_html( $name ), $tax ) ;
                
                if ( $term ) {
                    
                    $ids[] = $term->term_id ;
                    
                }
                
            }
        
        }
        
        return $ids ;
        
    }
   
}

$wp_plugin_template = new featured_thumbnail_fallbacks();

/**
 * ECHO FEATURED IMAGE
 * @param array $args
 */
function fatf_featured_image( $args ) {
    
    echo featured_thumbnail_fallbacks::show_featured_image( $args );
        
}

/**
 * IMPLEMENT GET FEATURED IMAGE URL
 * @param array $args
 * @return string
 */
function fatf_featured_image_url( $args ) {
    
    return featured_thumbnail_fallbacks::get_featured_image_url( $args );
    
}

// Add a link to the settings page onto the plugin page
if ( isset( $wp_plugin_template ) ) {
    
    // Add the settings link to the plugins page
    function fatf_plugin_settings_link( $links ) { 
        
        $settings_link = 
                '<a href="options-general.php?page=cks_fatf">Settings</a>'; 
        
        array_unshift( $links, $settings_link ); 
        
        return $links; 
        
    }

    $plugin = plugin_basename( __FILE__ ); 
    
    add_filter( "plugin_action_links_$plugin", 'fatf_plugin_settings_link' );
    
}

/* helper functions for install routine */
function fatf_merge_db_lists($list1, $list2) {
  $final_array = array();
  $final_array = fatf_go_through_list($list1, $final_array);
  $final_array = fatf_go_through_list($list2, $final_array);
  return $final_array;
}   

function fatf_go_through_list($list,$output){
  foreach (array_keys($list) as $key){
    if (array_key_exists($key, $output)){
      foreach ($list[$key] as $item ){
        $output[$key][] = $item;
      }  
      arsort($output[$key]);
    }
    else{
      $output[$key] = $list[$key];
    }  
  }
  return $output;
}

function arraysMergeUnique($array1, $array2)
{
    foreach ($array2 as $k => $v)
    {
        if ( is_array($array1) )
        {
            // If the meaning the value is a string, and doesn't already exist, add it
            if ( is_string($v) && ! in_array($v, $array1) )
            {
                $array1[] = $v;
            }
            // If the value's an array, make a recursive call with it
            else if ( is_array($v) )
            {
                if ( isset($array1[$k]) )
                {
                    $array1[$k] = $this->arraysMergeUnique($array1[$k], $v);
                }
                else
                {
                    $array1[$k] = $v;
                }
            }                
        }
        else
        {
            $array1 = array($v);
        }
    }
    
    return $array1;
}


