<?php

/**
 * Plugin Name: Link-Post Aggregator
 * Description: "Note and quote" while surfing, easily creating "Link-Posts" using WordPress's Press This tool, or assemble unique post archives via shortcode widget, or template - with extensive customization options.
 * Plugin URI:  http://www.ckmacleod.com/wordpress-plugins/linkposts/
 * Version:     0.995
 * Author:      CK MacLeod
 * Author URI:  http://www.ckmacleod.com/
 * License:     GPL
 * Text Domain: cks_lpa
 * Domain Path: /languages
 */

defined( 'ABSPATH' ) or die( 'Plugin file cannot be accessed directly. ' ) ;

register_activation_hook( __FILE__, 'cks_lpa_set_default_options' ) ;

if ( ! defined( 'CKS_LPA_VERSION' ) ) {
    
    define( 'CKS_LPA_VERSION', '0.995' ) ;
    
}

register_activation_hook( __FILE__, 'cks_rui_set_default_options' ) ;

/* VERSION CHECK AND UPGRADE ROUTINE */
add_action( 'plugins_loaded', 'cks_lpa_check_version' ) ;

function cks_lpa_check_version() {
    
    if ( CKS_LPA_VERSION !== get_option( 'cks_lpa_version') ) {
        
        cks_lpa_set_default_options() ;
        
    }
    
}

/** 
 * SET DEFAULT OPTIONS
 */
function cks_lpa_set_default_options() {
    
    //set extra stylesheet option/location separately - makes accessing/saving more convenient
    $stylesheet_location = plugin_dir_path( __FILE__ ) . 'css/cks_lpa_add_css.css' ;
    $stylesheet = file_get_contents( $stylesheet_location ) ;
    add_option( 'cks_lpa_style', $stylesheet ) ;
    
    //set general default options
    $cks_lpa_default_options = array(
	
        'table_title'       => __('Latest Links', 'cks_lpa'),           //the title shown at top of every table
        'hide_table_title'  => 0,                                       //whether to hide the table title (0 = NO, 1 = YES)
        'number_posts'      => 5,                                       //number of link-posts in table
        'order'             => 'DESC',                                  //order in which to display Link-Posts
        'orderby'           => 'date',                                  //meta by which to apply order - WP-Query terms appropriate
        'exclude_cat'       => '',                                      //category(ies) to exclude from table
        'include_cat'       => '',                                      //category(ies) to include in table
        'exclude_from_list' => 1,                                      //whether to exclude included cats from categories shown with post
        'alt_plus'          => '',                                      //an alternative to default "+" image
        'alt_minus'         => '',                                      //an alternative to default "-" image
        'no_source_link'    => 0,                                       //whether link-post title should link to original source or post
        'hide_post_cats'    => 0,                                       //whether to show the link-post's categories (other than the link-post category )
        'hide_post_tags'    => 0,                                       //whether to show the link-post's tags
        'hide_comments'     => 0,                                       //whether to show the Comments-Count Link
        'go_to_comments'    => __( 'Comment &rarr;', 'cks_lpa'),         //label for the link in "open" quote to comments thread
        'use_excerpt'       => 1,                                       //whether to use excerpt if present
        'more_text'         => __( 'Continued', 'cks_lpa'),             //Default Read More Text
        'use_wp_excerpt'    => 0,                                       //always use WordPress excerpt
        'cat_name'          => __( 'Link-Posts', 'cks_lpa'),            //the name of general category for all link-posts
        'cat_title'         => __( 'All Link-Posts &rarr;', 'cks_lpa'), //the label or title shown on the right bottom link
        'right_url'         => '',                                      //if desired, a link other than to category named above
        'show_right'        => 1,                                       //whether to hide a link to general category at all
        'left_title'        => __( '&larr; In the Web', 'cks_lpa'),     //the label or title shown in the left bottom link
        'left_url'          => '',                                      //a link other than to category named above
        'show_left'         => 0,                                       //whether to hide a second link (at left )
        'show_credit'       => 0,                                       //whether to show a credit-link back to developer's pages
        'conceal_from'      => '',                                      //one or a comma-separated list of category archives in which link-posts will not show
        'show_main'         => 0,                                       //whether to show link-posts as regular posts in main loop
        'show_author'       => 0,                                       //whether to show link-posts as regular posts in author archives
        'date_post'         => 0,                                       //show the post date-time for individual Link-Posts
        'date_post_format'  => 'g:i a',                                 //datetime format for Link-Post datetimes
        'day_group'         => 0,                                       //whether to group Link-Posts by day of week
        'day_group_format'  => 'l, m-d',                                //format for day group heading
        'week_group'        => 0,                                       //whether to group Link-Posts by week
        'week_group_format' => 'F j',                                   //format for dates in week group
        'week_title'        => __( 'Week of %1$s to %2$s', 'cks_lpa'),  //format/template for week group heading
        'month_group'       => 0,                                       //whether to group Link-Posts by month
        'month_group_format'=> 'F',                                     //datetime for month group heading
        'year_group'        => 0,                                       //whether to group Link-Posts by year
        'year_group_format' => 'Y',                                     //format for year group heading
        'no_lp_cat'         => 0,                                       //allow link-post table without category set
        'no_quote'          => 0,                                       //don't show the link-post "quote" content
        'use_thumbnail'     => 0,                                       //whether or not to include thumbnail images
        
    ) ;

    // convert old options using migrate option
    if ( get_option( 'cks_lpa_settings' ) ) {
        
        $options = get_option( 'cks_lpa_settings' ) ; 
        
        $legacy_options = migrate_lpa_pre93( $options ) ;
        
        $cks_lpa_default_options = 
                array_merge( $cks_lpa_default_options, $legacy_options ) ;
        
    }
    
    if ( ! empty( $options['include_cat'] ) ) { $options['include_cat'] = 
            cks_lpa_migrate_cats( $options['include_cat']) ; }
    if ( ! empty( $options['exclude_cat'] ) ) { $options['exclude_cat'] = 
            cks_lpa_migrate_cats( $options['exclude_cat']) ; }  
        
    
    update_option( 'cks_lpa_settings', $cks_lpa_default_options ) ;
    
    // register version number
    update_option( 'cks_lpa_version', CKS_LPA_VERSION ) ;
         
}

/**
 * get all option keys for simplified/shorter uses where
 * variables defined and sanitized
 */
function cks_lpa_array_keys() {
    
    $all_keys = Array(
    '0' => 'table_title',
    '1' => 'hide_table_title',
    '2' => 'number_posts',
    '3' => 'order',
    '4' => 'orderby',
    '5' => 'exclude_cat',
    '6' => 'include_cat',
    '7' => 'exclude_from_list',
    '8' => 'alt_plus',
    '9' => 'alt_minus',
    '10' => 'no_source_link',
    '11' => 'hide_post_cats',
    '12' => 'hide_post_tags',
    '13' => 'hide_comments',
    '14' => 'use_excerpt',
    '15' => 'more_text',
    '16' => 'cat_name',
    '17' => 'cat_title',
    '18' => 'right_url',
    '19' => 'show_right',
    #'20' => 'left_name',
    '21' => 'left_title',
    '22' => 'left_url',
    '23' => 'show_left',
    '24' => 'show_credit',
    '25' => 'conceal_from',
    '26' => 'show_main',
    '27' => 'show_author',
    '28' => 'date_post',
    '29' => 'date_post_format',
    '30' => 'day_group',
    '31' => 'day_group_format',
    '32' => 'week_group',
    '33' => 'week_group_format',
    '34' => 'week_title',
    '35' => 'month_group',
    '36' => 'month_group_format',
    '37' => 'year_group',
    '38' => 'year_group_format',
    '39' => 'no_lp_cat',
    '40' => 'no_quote',
    '41' => 'go_to_comments',
    '42' => 'use_thumbnail',
    '43' => 'use_wp_excerpt',
        
) ;
    
    return $all_keys ;
    
}

include_once( dirname( __FILE__ ) . '/migrate.php' ) ;
include_once( dirname( __FILE__ ) . '/admin.php' ) ;
include_once( dirname( __FILE__ ) . '/construct.php' ) ;
include_once( dirname( __FILE__ ) . '/widget.php' ) ;

/* INSTALLATION UTILITIES AND SCRIPTS */

/**
  * wrapper function for 
  * template table
  * @param array $args
  */
 function add_cks_lpa_table_to_template( $args = null ) {
     
    if ( is_array( $args ) ) {
     
        echo add_cks_lpa_table( '', '', $args ) ;
     
    } else {
     
        echo add_cks_lpa_table( $args, '', '' ) ;
    }
 }

/**
 * PLACE TABLE IN LOOP
 * ALLOW CONTEXTUAL PLACEMENT OF TABLE (AS FIRST POST OF THE DAY/IN LOOP) 
 * returns html and sets $flag when table is to be set
 */
function place_cks_lpa_table_in_loop( $args = null ) {

    static $flag;  
    
    if ( isset( $flag ) ) {
    
        return;
        
    }
    
    $current_day = current_time( 'l, m-d' ) ;
    
    $post_day = get_the_date( 'l, m-d' ) ;

    if ( ( $current_day != $post_day ) && ! is_paged() ) {

        echo add_cks_lpa_table( 'loop', '', $args ) ;
        
        $flag = true;

    }
   
}

/**
 * KEEP Linkposts POSTS FROM SHOWING IN REGULAR LOOP 
 * also excludes from specified category and author archives
 **/
add_action( 'pre_get_posts', 'exclude_categories_from_loop' ) ;

/**
 * CONCEAL VS SHOW LINK-POSTS FROM LOOP on FRONT PAGE, AUTHOR, AND/OR ARCHIVE PAGES
 * @param object $wp_query the main WP query object
 */
function exclude_categories_from_loop( $wp_query ) {

    $options = get_option( 'cks_lpa_settings' ) ;
    
   $show_main = isset( $options['show_main'] ) ? $options['show_main'] :  '' ;
   $show_author = isset( $options['show_author'] ) ? $options['show_author'] :  '' ;
   $excluded_archives = isset( $options['conceal_from'] ) ? $options['conceal_from'] :  '' ;

    $exclude_array = array() ;

    if ( $excluded_archives ) { $exclude_array = explode( ', ', $excluded_archives ) ; }
   
    if ( ( is_home() && ! $show_main ) ||  
            ( is_author() && ! $show_author ) || 
            ( $exclude_array && is_category( $exclude_array ) ) ) {

         $cat_name = esc_html( $options['cat_name'] ) ;
         $cat_id =  get_cat_ID( $cat_name ) ;

        $excluded = array( $cat_id ) ;

        set_query_var( 'category__not_in', $excluded ) ;

     }

}

/**
 * ADD CSS FUNCTIONS
 * ADD TO WP-HEAD, ENQUEUE SCRIPT
 */
add_action( 'wp_head', 'page_header_output' ) ;

function page_header_output() { ?>
            
    <style type='text/css'>
        
	<?php
        
            $option = get_option( 'cks_lpa_style' ) ;
        
            echo $option ;
            
	?>
        
    </style>
    
<?php }

/*ENQUEUE STYLESHEET */
function cks_lpa_stylesheet() {
    
    wp_enqueue_style( 
            'cks_lpa_stylesheet', 
            plugins_url( 'css/cks_lpa_style.css', __FILE__ ) . 
            '?v=' . CKS_LPA_VERSION 
            ) ;
    
}

add_action( 'wp_enqueue_scripts', 'cks_lpa_stylesheet' ) ;

/* ENQUEUE FRONT END JS */
function cks_front_js() {
    
    wp_enqueue_script(
        'cks_front',
        plugins_url( 'js/cks_front.js', __FILE__ ),
        array( 'jquery' )
    ) ;
    
}

add_action( 'wp_enqueue_scripts', 'cks_front_js' ) ;

/* FOR POSSIBLE TRANSLATION */
add_action( 'init', 'cks_lps_load_translation_file' ) ;
 
function cks_lps_load_translation_file() {
    
    // relative path to WP_PLUGIN_DIR where the translation files will sit:
    $plugin_path = plugin_basename( dirname( __FILE__ ) . '/languages' ) ;
    load_plugin_textdomain( 'cks_lpa', '', $plugin_path ) ;
    
}

/***
 * CUSTOMIZE PLUGIN OVERVIEW PAGE DISPLAY
 * Add settings link on plugin page
 */
function add_cks_lps_settings_link( $links ) { 
    
  $settings_link = '<a href="admin.php?page=cks_lpa">Settings</a>' ; 
  array_unshift( $links, $settings_link ) ; 
  
  return $links; 
  
}
 
$plugin = plugin_basename( __FILE__ ) ; 

add_filter( "plugin_action_links_$plugin", 'add_cks_lps_settings_link' ) ;