<?php

/*
Plugin Name: State of the Discussion
Plugin URI:
Description: Lists last n comments with links to commenter, post, comment text or excerpt, and other useful information
Author: Michael Cain, based on a plugin by CK MacLeod
Version: 1.1
Author URI:
*/

//
//	Enqueue the stylesheet (one file for everything) and the JavaScript used for the SOTD toggle
//

add_action('wp_enqueue_scripts', 'sod_stylesheet');
add_action('wp_enqueue_scripts', 'sotd_toggle');

function sod_stylesheet()
{
    wp_enqueue_style('sodstyle', plugins_url('stylesheet.css', __FILE__));
}

function sotd_toggle()
{
    wp_enqueue_script('togglediv', plugins_url('togglediv.js', __FILE__), array(
        'jquery'
    ));
}


//
//	Page version of SOTD
//

add_shortcode('sotd', 'add_sod_page');

function add_sod_page($atts)
{

    extract(shortcode_atts(array(
        'total_comments' => '48',
        'length_excerpt' => '25',
        'num_columns' => '2',
        'num_colors' => '18',
        'catchall_color' => '#fff',
        'avatar_size' => '60'
    ), $atts));

//base variables for pagination
    $paged              = (get_query_var('paged')) ? get_query_var('paged') : 1;
    $offset             = ($paged - 1) * $total_comments;
    $all_comments       = wp_count_comments();
    $all_comments_count = $all_comments->approved;
    
    $comments = get_comments(array(
        'status' => 'approve',
        'number' => $total_comments,
        'offset' => $offset
    ));
    
    $total_pages = intval($all_comments_count / $total_comments) + 1;
    
    
//pagination
    if ($all_comments_count > $total_comments) {
        echo '<div class="page_nav page_nav_top clearfix">';
        paginate_sod($total_pages);
    }
    
//open sod div
    echo '<div class="sod" id="sod">';
    
//open legend div
    echo '<div id="post-legend" class="post-legend">';
    echo '<p class="sod" style="font-size:18px; margin:12px 0 0 0;">The posts in play...</p>';
    
//initialize variables
    $catchall_color = 'catchall';
    
//arrays
    $used_posts     = array();
    $used_indices   = array();
    $catchall_posts = array();
    
//first foreach for posts section
    foreach ($comments as $comment) {
        
        $current_post_ID = $comment->comment_post_ID;
        
        $color_index = ($current_post_ID % $num_colors);				//assign basic color index
        
        if (!in_array($current_post_ID, $used_posts)) {					//is new post
            
            if (in_array($color_index, $used_indices)) {				//color index already assigned [new post, old index]
                $post_color       = $catchall_color;					// if new post/old index, assign catchall
                $catchall_posts[] = $current_post_ID;					//add post to catchall posts array
                $used_posts[]     = $current_post_ID;					//add post to used posts
            }
			else {														//color_index not yet assigned
                $post_color     = $color_index;							//assign color index to new post
                $used_indices[] = $color_index;							//add color index to used indices
                $used_posts[]   = $current_post_ID;						//add post to used posts
            }
            $current_post        = get_post($current_post_ID);			// get post object
            $current_author_ID   = $current_post->post_author;
            $current_author_url  = get_author_posts_url($current_author_ID);
            $current_author_name = get_the_author_meta('display_name', $current_author_ID);
            
?>
    <div class="legend-post sod-color-<?php
            echo $post_color;
?>">
        <div class="legend-post-avatar">
            <?php

//use linkage image instead of avatar for link posts
            if (!in_category('linkage', $current_post_ID)) {
                echo get_avatar($current_author_ID, 40);
            }
			else {
                echo '<img class="avatar" src="' . plugins_url('linkage-image.png', __FILE__) . '" title="Linkage" />';
            }
?>
        </div>
        <div class="legend-post-title">
        <a href="<?php
            echo get_permalink($current_post_ID);
?>" title="Go to post" />
	<?php
            echo get_the_title($current_post_ID) . '</a>';
?>
        </div>
        <a class="legend-comment-count" href="<?php
            echo get_permalink($current_post_ID);
?>#comments" title="Go to Comments" />(<?php
			echo get_comments_number($current_post_ID);
?>)</a>
	<div class="comment-exc" id="exc-<?php
            echo $current_post_ID;
?>">
            <a class="sod-legend-plus" href="javascript:toggleDiv('<?php
            echo $current_post_ID;
?>');" title="Show Excerpt" />+</a>
	</div>
	<div class="fulltext comment-full" id="comment-full-<?php
            echo $current_post_ID;
?>" style="display: none;">
            <a href="javascript:toggleDiv('<?php
            echo $current_post_ID;
?>');" class="sod-legend-minus sod-legend-minus-begin" title="Close" />-</a>
            <?php

//excerpt not showing - also 12px padding better for excerpts, author by-line should be optional, add "view post" to arrow
//other changes including to stylesheet, update with OT current and other stuff 
//LINKAGE MODIFICATION
//          if (in_category('linkage', $current_post_ID)) {
//              echo apply_filters('the_content', $current_post->post_content);
//          }
//			else {
                if (!apply_filters('the_excerpt', $current_post->post_excerpt)) {
                    the_excerpt();
                }
				else {
                    echo apply_filters('the_excerpt', $current_post->post_excerpt);
                }
//          }

?>
            <a href="<?php
            echo get_permalink($current_post_ID);
?>" title="Go to post" class="sod-legend-view-post" />View Post &rarr;</a>
            <a href="javascript:toggleDiv('<?php
            echo $current_post_ID;
?>');" class="sod-legend-minus sod-legend-minus-end" title="Close"
               />-</a>	
	</div>
    </div>
<?php
        }
    }
    get_uncommented_recents();
    echo '</div>';
    echo '<div style="clear:both; height:1px;">&nbsp;</div>'; //clearfix
    echo '<p class="sod" style="font-size:18px; margin:12px 0 -0.2em 0;">The comments...</p>';

//second foreach, for the comment section
    
    $num_comments = 0;
    
    foreach ($comments as $comment) {
        
        $current_post = $comment->comment_post_ID;					//could be assigned with initial "get" so would freach $post_ids
        $color_index  = ($current_post % $num_colors);				//assign basic color index 
        
        if (!in_array($current_post, $used_posts)) {				//is new post
            if (in_array($color_index, $used_indices)) {			//color index already assigned [new post, old index]
                $post_color       = $catchall_color;				// if new post/old index, assign catchall
                $catchall_posts[] = $current_post;					//add post to catchall posts array
                $used_posts[]     = $current_post;					//add post to used posts
            }
			else {													//color_index not yet assigned
                $post_color     = $color_index;						//assign color index to new post
                $used_indices[] = $color_index;						//add color index to used indices
                $used_posts[]   = $current_post;					//add post to used posts
            }
        }
		else {														//is old post
            if (!in_array($current_post, $catchall_posts)) {		//old post not in catchall posts array
                $post_color = $color_index;							//assign initial color index to old posts not catchall posts
            }
			else {													//post is old post and color is catchall
                $post_color = $catchall_color;
            }
        }
        
//produce end row class	- needs for each comments_IDs only 
        $num_comments++;
        if ($num_comments == $num_columns) {
            $end_row_class = 'sod-endrow';
            $num_comments  = 0;
        }
		else {
            $end_row_class = '';
        }
        
//      if (get_comment_meta($comment->comment_ID, 'featured', true)) {
//          $featured_class = ' featured';
//      } else {
//          $featured_class = '';
//      }
		$featured_class = '';
        
?>
    <div class="sod-comment <?php
        echo $end_row_class;
?> <?php
        echo $featured_class;
?> sod-color-<?php
        echo $post_color;
?>" id="comment-<?php
        echo $comment->comment_ID;
?>"  />
        <div class="comment-heading">
            <div class="comment-datetime"><a href="<?php
        echo get_comment_link($comment);
?>" title="Go to comment" /><?php
        $currentTime = current_time('timestamp');
        $commentTime = mysql2date('U', $comment->comment_date);
        $timeDiff    = $currentTime - $commentTime;
        if ($timeDiff <= (30 * 86400)) {
            $timestamp = sprintf('%s ago', human_time_diff($commentTime, $currentTime));
        }
		else {
            $timestamp = $comment->comment_date;
        }
        echo $timestamp;
?></a>
            </div>
            <div class="comment-irt">
            <?php
        if ($comment->comment_parent != '0') {
?>
            <a href="<?php
            $commentparent     = get_comment($comment->comment_parent);
            $commentparentpage = get_page_of_comment($commentparent);
            echo htmlspecialchars(get_comment_link($commentparent, array(
                'page' => $commentparentpage
            )));
?>" title="Go to comment replied to">
            to <?php
            echo $commentparent->comment_author;
?></a>
            <?php
        }
?>
            </div>
        </div>
        <div class="comment-author"><?php
//      echo get_avatar($comment->comment_author_email, $avatar_size);
		echo get_avatar($comment->comment_author_email);
?><span class="comment-author-name"><?php
        echo get_comment_author_link($comment->comment_ID);
?></span>
        </div>	
        <div class="comment-text">
            <?php
        $comment_text = $comment->comment_content;
        //added to work with "Pseudo-Redacter/Spoilerer"
        $test_text    = str_replace(array(
            '<span class="spoiled">',
            '</span>',
            '<blockquote>',
            '</blockquote>'
        ), array(
            '[span class="spoiled"]',
            '[/span]',
            '[span style="font-style:italic"]',
            '[/span]'
        ), $comment_text);
        $test_text    = wp_strip_all_tags($test_text);
        $test_text    = str_replace(array(
            '[span class="spoiled"]',
            '[/span]',
            '[span style="font-style:italic"]'
        ), array(
            '<span class="spoiled">',
            '</span>',
            '<span style="font-style:italic">'
        ), $test_text);
        $words        = explode(' ', $test_text, $length_excerpt + 1);
        if (count($words) > $length_excerpt) {
            array_pop($words);
            $exc_comment_text = implode(' ', $words);
            $exc_comment_text .= '</span> <a href="' . get_comment_link($comment) . '">[. . .]</a>';
?>
                <div class="comment-exc" id="exc-<?php
            echo $comment->comment_ID;
?>">
                    <a class="sod-toggle-plus" href="javascript:toggleDiv('<?php
            echo $comment->comment_ID;
?>');" />+</a>
                    <?php
            echo $exc_comment_text;
?>
                </div>
                <div class="comment-full" id="comment-full-<?php
            echo $comment->comment_ID;
?>" style="display: none;">
                    <a href="javascript:toggleDiv('<?php
            echo $comment->comment_ID;
?>');" class="sod-toggle-minus">-</a>
                    <?php
            echo force_balance_tags(wpautop($comment_text));
?><a href="<?php
            echo get_comment_link($comment);
?>" style="float: left;">[View in thread]</a>
                    <a href="javascript:toggleDiv('<?php
            echo $comment->comment_ID;
?>');" class="sod-toggle-minus sod-toggle-end" />-</a>
                </div>
                <?php
        }
		else {
?>
                <div class="short-comment" id="short-comment-<?php
            echo $comment->comment_ID;
?>">
                <?php
            $comment_text = wpautop($comment_text);
            $comment_text = str_replace(array(
                '<blockquote>',
                '</blockquote>'
            ), array(
                '<span style="font-style: italic">',
                '</span>'
            ), $comment_text);
            echo force_balance_tags(wpautop($comment_text));
?>
                </div>
                <?php
        }
?>	
            </div>
            <div class="sod-comment-footer">
                <div class="commenter-archives">
                    <?php
        print_commenter_archive_links($comment);
?>
                </div>
                <div class="sod-post-title">
                    <a href="<?php
        echo get_permalink($comment->comment_post_ID);
?>" title="Go to post" />
                    <?php
        echo get_the_title($comment->comment_post_ID);
?></a>
                </div>
            </div>
    </div>
<?php

    } //end foreach
    
//close sod-wrapper
    
    echo '</div>'; //sod page wrapper
    
    echo '<div style="clear:both; height:1px;">&nbsp;</div>'; //clearfix
    
//pagination - note: virtuall repeats prior pagination so almost certainly could be condensed
    if ($all_comments_count > $total_comments) {
        echo '<div class="page_nav page_nav_bottom clearfix">';
        paginate_sod($total_pages);
    }
}


//
//	Support routines for the page version of SOTD
//	Pagination
//	Commenter archive links
//	  used to open in new windows or tabs, but that's commented out now
//	Get posts that have not yet been commented on
//

function paginate_sod($total_pages)
{
    													//Get variable is interposed when using un-modified get_pagenum_link
    													//so use pre_replace in base variable of paginate_links array [2]
    
    $current_page = max(1, get_query_var('paged'));
    echo paginate_links(array(
        'base' => get_pagenum_link(1) . '%_%',
        'current' => $current_page,
        'total' => $total_pages,
        'prev_text' => __('&laquo; Previous'),
        'next_text' => __('Next &raquo;'),
        'end_size' => 2,
        'mid-size' => 3
    ));
    echo '</div>';										//pagination
}

function print_commenter_archive_links($comment)
{
    $cid = $comment->comment_ID;

    echo '<a class="cthread_open" title="View Comments on This Thread by '
		. $comment->comment_author
//		. '" onclick="window.open(this.href, \'threadwindow\',\'right=20,top=20,width=500,height=640,scrollbars=yes,resizable=yes,location=no,menubar=no,toolbar=no\'); return false;"'
		.'" href="'
		. esc_url(home_url('/'))
		. 'commenter-thread?cid='
		. $cid
		. '&cthread=true" rel="nofollow"><img class="comments-thread-icon" src="'
		. plugins_url('comments_40px.png', __FILE__)
		. '" alt="Comments this thread"  /></a>';

    echo '<a class="c-archive-open" title="Commenter Archive for '
		. $comment->comment_author
		. '" href="'
		. esc_url(home_url('/'))
		. 'commenter-archive?cid='
		. $cid
//		. '" rel="nofollow" target="_blank" /><img class="comment-archive-icon" src="'
		. '" rel="nofollow"><img class="comment-archive-icon" src="'
		. plugins_url('comment_archive_40px.png', __FILE__)
		. '" alt="Commenter Archive"  /></a>';
}

function get_uncommented_recents()
{
    
    $is_paged = get_query_var('paged');
    if (!$is_paged) {
        
        $recent_args = (array(
            'numberposts' => 6,
            'post_status' => 'publish'
        ));
        
        $recent_posts = wp_get_recent_posts($recent_args, OBJECT);
        $rps          = 0;
        foreach ($recent_posts as $recent_post) {
			$actual_comments = get_comments_number($recent_post->ID);
            if ($actual_comments == 0) {
                $rps++;
            }
        }
        
        if ($rps > 0) {
            
        }
        
        foreach ($recent_posts as $recent_post) {
            /* ADDED FOR LINKAGE TO LINKAGE */
            //if (! in_category('linkage',$recent_post->ID)) { 
			$actual_comments        = get_comments_number($recent_post->ID);
            $post_time              = strtotime($recent_post->post_date);
            $recent_post_lookback   = (3600 * 48);
            $recent_post_time_limit = strtotime(current_time('mysql')) - $recent_post_lookback;
            
            if (($actual_comments == 0) && ($post_time > $recent_post_time_limit) && (comments_open($recent_post->ID))) {
                
                $current_post_ID = $recent_post->ID;
                setup_postdata($recent_post);
                $current_author_ID = $recent_post->post_author;
?> 

			<div class="legend-post uncommented" >
				
				<div class="legend-post-avatar">
					<?php
                //use linkage image instead of avatar for link posts
                /*ADDED FOR LINKAGE LINKAGE 
                SHOW LINKAGE IMAGE INSTEAD OF AUTHOR AVATAR
                */
                if (!in_category('linkage', $current_post_ID)) {
                    echo get_avatar($current_author_ID, 40);
                } else {
                    echo '<img class="avatar" src="' . plugins_url('linkage-image.png', __FILE__) . '" title="Linkage" />';
                }
?>
				</div>
				<div class="legend-post-title">
				<a href="<?php
                echo get_permalink($current_post_ID);
?>" title="Go to post" />
				<?php
                echo get_the_title($current_post_ID) . '</a>';
?>
				</div>
				<a class="legend-comment-count" href="<?php
                echo get_permalink($current_post_ID);
?>#comments" title="Go to Comments" />(No Comments Yet)</a>
				<div class="comment-exc" id="exc-<?php
                echo $current_post_ID;
?>">
					<a class="sod-legend-plus" href="javascript:toggleDiv('<?php
                echo $current_post_ID;
?>');" title="Show Excerpt" />+</a>
				</div>
				<div class="fulltext comment-full" id="comment-full-<?php
                echo $current_post_ID;
?>" style="display: none;">
					<a href="javascript:toggleDiv('<?php
                echo $current_post_ID;
?>');" class="sod-legend-minus-begin" title="Close" />-</a>
					<?php //excerpt not showing - also 12px padding better for excerpts, author by-line should be optional, add "view post" to arrow
                //other changes including to stylesheet, update with OT current and other stuff 
                //LINKAGE MODIFICATION
//              if (in_category('linkage', $current_post_ID)) {
//                  echo apply_filters('the_content', $recent_post->post_content);
//              }
//				else {
                    if (!apply_filters('the_excerpt', $recent_post->post_excerpt)) {
                        the_excerpt();
                    } else {
                        echo apply_filters('the_excerpt', $recent_post->post_excerpt);
                    }
//              } # linkage
                //END LINKAGE MODIFICATION
?>
					<a href="<?php
                echo get_permalink($current_post_ID);
?>" title="Go to post" class="sod-legend-view-post" />View Post &rarr;</a>
					<a href="javascript:toggleDiv('<?php
                echo $current_post_ID;
?>');" class="sod-legend-minus sod-legend-minus-end" title="Close"
					   />-</a>	
				</div>
			</div>

		<?php
            }
            
        }				#foreeach 
    }					#is_paged
}						#function


//
//	SOTD widget version
//	Not really a widget in the sense that WordPress uses, with the use of class and all
//	Simply a plugin with sizes and arrangement suitable for use in a sidebar
//	Use the shortcode in a text widget to do the actual placement
//

add_shortcode('sotd-widget', 'sod_widget');

function sod_widget($atts)
{
    extract(shortcode_atts(array(
        'total_comments' => '10',
        'length_excerpt' => '25',
        'num_colors' => '18',
        'avatar_size' => '60'
    ), $atts));

    $comments = get_comments(array(
        'status' => 'approve',
        'number' => $total_comments + 1,
        'type__not_in' => array(
            'trackback',
            'pingback'
        )
    ));

    //static variables
    
    $number_comments = 0;
    
    $catchall_color = 'catchall';
    
    //arrays
    
    $used_posts     = array();
    $used_indices   = array();
    $catchall_posts = array();
    
    //open commentariat div
    
    echo '<div id="sod-widget">';
	echo '<div class="commentariat">Recent Comments</div>';
    
    //produce comment list, keeping track of number of comments
    
    foreach ($comments as $comment) {
        
        $number_comments++;
        if ($number_comments == $total_comments + 1) {
            $next_anchor = '#comment-' . $comment->comment_ID;
        }

		else {
//produce featured class
//          if (get_comment_meta($comment->comment_ID, 'featured', true)) {
//              $featured_class = ' featured';
//          }
//			else {
//              $featured_class = '';
//          }
			$featured_class = '';
            
            $current_post = $comment->comment_post_ID;
            $color_index  = ($current_post % $num_colors);				//assign basic color index 
            
            if (!in_array($current_post, $used_posts)) {				//is new post
                if (in_array($color_index, $used_indices)) {			//color index already assigned [new post, old index]
                    $post_color       = $catchall_color;				// if new post/old index, assign catchall
                    $catchall_posts[] = $current_post;					//add post to catchall posts array
                    $used_posts[]     = $current_post;					//add post to used posts
                }
				else { //color_index not yet assigned
                    $post_color     = $color_index;						//assign color index to new post
                    $used_indices[] = $color_index;						//add color index to used indices
                    $used_posts[]   = $current_post;					//add post to used posts
                }
            }
			else {														//is old post
                if (!in_array($current_post, $catchall_posts)) {		//old post not in catchall posts array
                    $post_color = $color_index;							//assign initial color index to old posts not catchall posts
                }
				else {													//post is old post and color is catchall
                    $post_color = $catchall_color;
                }
            }
?>
	<div class="commentariat-comment <?php
            echo $featured_class;
?> sod-color-<?php
            echo $post_color;
?>" id="comment-<?php
            echo $comment->comment_ID;
?>"  />
		<div class="comment-heading">
			<div class="comment-datetime"><a href="<?php
            echo get_comment_link($comment);
?>" title="Go to comment"/><?php
            $currentTime = current_time('timestamp');
            $commentTime = mysql2date('U', $comment->comment_date);
            $timeDiff    = $currentTime - $commentTime;
            if ($timeDiff <= (30 * 86400)) {
                $timestamp = sprintf('%s ago', human_time_diff($commentTime, $currentTime));
            }
			else {
                $timestamp = $comment->comment_date;
            }
            echo $timestamp;
?></a>
			</div>
			<div class="comment-irt">
				<?php
            if ($comment->comment_parent != '0') {
                $commentparent     = get_comment($comment->comment_parent);
                $commentparentpage = get_page_of_comment($commentparent);
				if ($commentparent && $commentparent->comment_author) {
					echo '<a href="';
                	echo htmlspecialchars(get_comment_link($commentparent, array(
                   		'page' => $commentparentpage
                	)));
					echo '" title="Go to comment replied to" />to ';
                	echo $commentparent->comment_author;
					echo '</a>';
				}
            }
?>
			</div>
		</div>
		<div class="comment-author"><?php
//          echo get_avatar($comment->comment_author_email, $avatar_size);
			echo get_avatar($comment->comment_author_email);
?><span class="comment-author-name"><?php
            echo get_comment_author_link($comment->comment_ID);
?></span>
			<div class="commenter-archives">
			<?php
            print_commenter_archive_links($comment);
?>
			</div>
		</div>	

		<div class="comment-text">
			<?php
            $comment_text = $comment->comment_content;
            //added to work with "Pseudo-Redacter/Spoilerer"
            $test_text    = str_replace(array(
                '<span class="spoiled">',
                '</span>',
                '<blockquote>',
                '</blockquote>'
            ), array(
                '[span class="spoiled"]',
                '[/span]',
                '[span style="font-style:italic"]',
                '[/span]'
            ), $comment_text);
            $test_text    = wp_strip_all_tags($test_text);
            $test_text    = str_replace(array(
                '[span class="spoiled"]',
                '[/span]',
                '[span style="font-style:italic"]'
            ), array(
                '<span class="spoiled">',
                '</span>',
                '<span style="font-style:italic">'
            ), $test_text);
            $words        = explode(' ', $test_text, $length_excerpt + 1);

//prepare an excerpt and the full comment
//with toggle

            if (count($words) > $length_excerpt) {
                array_pop($words);
                $exc_comment_text = implode(' ', $words);
                
//clean up tag fragments
//$exc_comment_text = str_replace( array('[', ']'), array('<','>'), $exc_comment_text);
//extra close span tag shouldn't come up too often but is kludgy
                $exc_comment_text .= '</span> <a href="' . get_comment_link($comment) . '">[. . .]</a>';
?>
			<div class="comment-exc" id="exc-<?php
                echo $comment->comment_ID;
?>">
				<a class="sod-toggle-plus" href="javascript:toggleDiv('<?php
                echo $comment->comment_ID;
?>');" />+</a>
				<?php
                echo force_balance_tags($exc_comment_text);
?>
			</div>
			<div class="comment-full" id="comment-full-<?php
                echo $comment->comment_ID;
?>" style="display: none;">
				<a href="javascript:toggleDiv('<?php
                echo $comment->comment_ID;
?>');" class="sod-toggle-minus">-</a>
				<?php
                echo force_balance_tags(wpautop($comment_text));
?><a href="<?php
                echo get_comment_link($comment);
?>" style="float: left;">[View in thread]</a>
				<a href="javascript:toggleDiv('<?php
                echo $comment->comment_ID;
?>');" class="sod-toggle-minus sod-toggle-end" />-</a>
			</div>
			<?php

            }

//prepare a short comment
//no toggle
			else {
?>
			<div class="short-comment" id="short-comment-<?php
                echo $comment->comment_ID;
?>">
				<?php
                
                $comment_text = wpautop($comment_text);
                $comment_text = str_replace(array(
                    '<blockquote>',
                    '</blockquote>'
                ), array(
                    '<span style="font-style: italic">',
                    '</span>'
                ), $comment_text);
                echo force_balance_tags($comment_text);
?>
			</div>
			<?php

            }
?>			
		</div>
		<div class="commentariat-post-title">
			<a href="<?php
            echo get_permalink($comment->comment_post_ID);
?>" title="Go to post" />
			<?php
            echo get_the_title($comment->comment_post_ID);
?></a>
		</div>
	</div>

	<?php

        }				//less than total_comments + 1

    }					//end foreach
    
//close commentariat-wrapper
    
    echo '</div>'; //commentariat page wrapper
//  echo '<a id="sod_open" title="View More Comments" onclick=" window.open(this.href, \'popup-sod\',\'right=50%,top=0,width=350,height=640,scrollbars=yes,resizable=yes,location=yes,menubar=yes,toolbar=yes\'); return false;" href="' . esc_url(home_url('/')) . 'state-of-the-discussion/' . $next_anchor . '" rel="nofollow">View More &rarr;</a>';
    echo '<a id="sod_open" title="View More Comments" href="'
		. esc_url(home_url('/'))
		. 'state-of-the-discussion/" rel="nofollow" style="font-size:16px; margin-top:16px; margin-bottom:0;">View More comments &rarr;</a>';

}



//
//	Commenter comment archives for SOTD
//	CK had this stuff scattered all over his custom theme
//	Decided to put it all here, and the CSS in the SOTD stylesheet.css, since Will doesn't want the new theme code touched
//	First one -- commenter-thread CSS -- is all comments by commenter on current post
//	Second one -- commenter-archive CSS -- is all comments by commenter on ALL posts
//


add_shortcode('commenter-thread','commenter_thread');

function commenter_thread() {

	if (isset($_GET['cid'])) { 
		$cid = $_GET['cid'];
		$thecomment = get_comment($cid);
		$pid = $thecomment->comment_post_ID;
		$thecommenter = $thecomment->comment_author;
		$c_author_email = $thecomment->comment_author_email;
	 }
	 else {
	 	echo 'You do not belong here.';
	 	exit;
	 }

	$comments = get_comments(array(
		'author_email' => $c_author_email,
		'status' => 'approve',
		'post_id' => $pid
	));
	
	echo '<div class="commenter-thread">';			
	echo '<div class="commenter-thread-head">';
	echo '<div class="commenter-thread-avatar">' . 
	get_avatar($thecomment->comment_author_email) . 
		'</div><div class="commenter-thread-title">Comments on <a href="' . get_permalink( $pid) . '">' . get_the_title($pid) . '</a> by ' . get_comment_author_link($thecomment->comment_ID) .  '</div>';
	echo '</div>';

//produce comment list, keeping track of number of comments

	foreach($comments as $comment) { 
		
?> 
	
<div class="commenter-thread-comment" id="li-<?php echo $comment->comment_ID ?>">
	<div class="commenter-thread-comment-head">
		<div class="comment-datetime"><a href="<?php echo get_comment_link($comment);?>" /><?php 
			$currentTime = current_time('timestamp');
			$commentTime = mysql2date('U', $comment->comment_date);
			$timeDiff = $currentTime - $commentTime;
			if($timeDiff <= (30 * 86400)) {
				$timestamp = sprintf('%s ago', human_time_diff($commentTime, $currentTime));
			} else {
				$timestamp = $comment->comment_date;
			}
			echo $timestamp;?></a>
		</div>
		<div class="comment-irt">
			<?php if ($comment->comment_parent != '0') : ?>
			<a href="<?php
			$commentparent = get_comment($comment->comment_parent);
			$commentparentpage = get_page_of_comment($commentparent);
			echo htmlspecialchars(get_comment_link( $commentparent, array('page' => $commentparentpage) ) ); ?>"> to <?php echo $commentparent->comment_author ; ?></a><?php endif; ?>
		</div>
	</div>
	<div class="commenter-thread-text" id="text-<?php echo $comment->comment_ID ?>">
		<?php echo force_balance_tags(wpautop($comment->comment_content)); ?>
	</div>
</div>

	<?php

	}				//end foreach

//close commentariat-wrapper
//link to commenter-archive

	echo '<div style="clear:both; height:1px;">&nbsp;</div>';
	echo '<div class="cthread-icon-footer"><a class="c-archive-open" title="Commenter Archive for '
		. $comment->comment_author
		. '"	href="' 
		. esc_url( home_url( '/' ))
		. 'commenter-archive?cid='
		. $cid
		. '" rel="nofollow"><img class="comment-archive-icon" src="'
		. plugins_url('comment_archive_40px.png', __FILE__)
		. '" alt="Commenter Archive"  /></a></div>';

	echo '</div>'; 

}					// end function


//
// Commenter full archive
//

add_shortcode('commenter-archive','commenter_archive');

function commenter_archive() {

	ini_set("memory_limit","-1");

	if (isset($_GET['cid'])) {
		$cid = $_GET['cid'];
		$thecomment = get_comment($cid);
		$pid = $thecomment->comment_post_ID;
		$thecommenter = $thecomment->comment_author;
		$c_author_email = $thecomment->comment_author_email;
		$userid = $thecomment->user_id;
	}
	else {
		echo 'You do not belong here. Go away.';
		exit;
	}

	$number = 25;
	
	$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

	$offset = ($paged - 1) * $number;


	if ($userid > 0) {

		$commenter_link = '<a href="' . get_author_posts_url($userid) . '" title="Posts by ' . $thecommenter . '" />' . $thecommenter . '</a>';
	
		$comments = get_comments(array(
			'user_id' => $userid,
			'status' => 'approve'
		));
	
		$comment_subquery = get_comments(array(
			'user_id' => $userid,
			'status' => 'approve',
			'offset' => $offset,
			'number' => $number
		));

	}
	else {

		$commenter_link = get_comment_author_link($cid) . '*' ;
	
		$comments = get_comments(array(
			'author_email' => $c_author_email,
			'status' => 'approve'
		));
	
		$comment_subquery = get_comments(array(
			'author_email' => $c_author_email,
			'status' => 'approve',
			'offset' => $offset,
			'number' => $number
		));
	}

	$total_comments = count($comments);
	$total_subquery = count($comment_subquery);
	$total_pages = intval($total_comments / $number) + 1;	
	$old_pid = 0;

																	//general solution from Hongkiat as adapted [1]
	echo '<div class="commenter-archive">';
	
	if ($total_comments > $total_subquery) {						//pagination begin
		echo '<div class="page_nav page_nav_top clearfix">';
	  	$current_page = max(1, get_query_var('paged'));
	  
	//Get variable is interposed when using un-modified get_pagenum_link
	//so use pre_replace in base variable of paginate_links array [2]

		echo paginate_links(array(
			'base' => preg_replace('/\?.*/', '', get_pagenum_link(1)) . '%_%',
		        'current' => $current_page,
		        'total' => $total_pages,
		        'prev_text' => __('&laquo; Previous'),
			'next_text' => __('Next &raquo;'),
			'add_args' => array( 'cid' => get_query_var('cid')),
			'end_size' => 2,
			'mid-size' => 3
		));
		echo '</div>'; //pagination end
	}

	//HEADING 
	echo '<div class="commenter-archive-heading">';
		//avatar 
		echo '<span class="commenter-archive-avatar">' . 
		get_avatar($c_author_email,50) . 
		'</span>';
			
		// title/author
		echo '<span class="commenter-archive-title">Comments by ' . $commenter_link .  '</span>';
	echo '</div>'; 
	//heading

	//comment
	echo '<div class="commenter-archive-comments">';
	
	foreach($comment_subquery as $comment) { 
		$current_pid = $comment->comment_post_ID;

		//comment
		
		echo '<div class="commenter-archive-comment">';
	
		//if comment belong to different post show title of post
		if ($old_pid <> $current_pid) { ?>	
			<div class="commenter-archive-post-title">
				<h4>On &ldquo;<a href="<?php echo get_permalink( $current_pid ); ?>"><?php echo get_the_title($current_pid);?></a>&rdquo;</h4>
			</div>
<?php	 }
		else { ?>	
			<div class="commenter-archive-post-con-title">
				<h4><a href="<?php echo get_permalink( $current_pid ); ?>">
				&quot;</a></h4>
			</div>
<?php	} ?>
		<div class="comment-datetime"><a href="
			<?php echo get_comment_link($comment);?>"><?php echo $comment->comment_date;?></a></span>
		</div>
		<div class="comment-irt">
			<?php if ($comment->comment_parent != '0') : ?>
			<a href="<?php
			$commentparent = get_comment($comment->comment_parent);
			$commentparentpage = get_page_of_comment($commentparent);
			echo htmlspecialchars(get_comment_link( $commentparent, array('page' => $commentparentpage) ) ); ?>"> to 
			<?php echo $commentparent->comment_author ; ?>
			</a>
			<?php endif; ?>
		</div>
		<div class="commenter-archive-text" id="text-<?php echo $comment->comment_ID ?>">
			<?php echo force_balance_tags(wpautop($comment->comment_content)); ?>
		</div>
<?php 
		echo '</div>'; //comment
		
		$old_pid = $current_pid;	//reset old post variable for re-comparison
	}								//end foreach
	
	if ($userid == 0) {
		echo '<p class="archive-note">*Comment archive for non-registered commenters assembled by email address as provided.</p>';
	} 
	
	echo '</div>';					//comments


	//Pagination Bottom general solution from Hongkiat as adapted [1]

	if ($total_comments > $total_subquery) {
		echo '<div class="page_nav page_nav_bottom clearfix">';
		$current_page = max(1, get_query_var('paged'));
  
	//Get variable is interposed when using un-modified get_pagenum_link
	//so use pre_replace in base variable of paginate_links array [2]

		echo paginate_links(array(
			'base' => preg_replace('/\?.*/', '', get_pagenum_link(1)) . '%_%',
   	     		'current' => $current_page,
	        	'total' => $total_pages,
   		     	'prev_text' => __('&laquo; Previous'),
			'next_text' => __('Next &raquo;'),
			'add_args' => array( 'cid' => get_query_var('cid')),
			'end_size' => 2,
			'mid-size' => 3
   		 ));
		echo '</div>';				//pagination
	}								//end pagination
	
	echo '</div>';					//Commenter Archive

}


//
// Code to add an "in reply to" link in most cases
// Basically, any place the uses get_comment_author_link() to get the name/link for the comment author
//

add_filter('get_comment_author_link', 'ordinary_reply_to', 10, 3);

function ordinary_reply_to($author_link, $author, $comment_id) {
	$comment = get_comment($comment_id);
	if ($comment && $comment->comment_parent && $comment->comment_parent != '0') {
		$parent_comment = get_comment($comment->comment_parent);
		$parent_author = $parent_comment->comment_author;
		$parent_page = get_page_of_comment($parent_comment);
		$parent_link = htmlspecialchars(get_comment_link($parent_comment, array( 'page' => $parent_page)));
		$author_link .= '<span class="sod-hidden" style="font-weight:normal;"> in reply <a href="'
					 .  $parent_link
					 .  '" title="Go to parent comment"> to '
					 .  $parent_author
					 .  '</a></span>';
	}
	return $author_link;
}


//
// Define function typecore_site_title to override the default in the typecore theme
// Goal here is that all pages have the same site header as the front page
//

function typecore_site_title() {
		
	$custom_logo_id = get_theme_mod( 'custom_logo' );
	$logo = wp_get_attachment_image_src( $custom_logo_id , 'full' );
		
	// Text or image?
	if ( has_custom_logo() ) {
		$logo = '<img src="'. esc_url( $logo[0] ) .'" alt="'.esc_attr( get_bloginfo('name')).'">';
	} else {
		$logo = esc_html( get_bloginfo('name') );
	}
		
	$link = '<a href="'.esc_url( home_url('/') ).'" rel="home">'.$logo.'</a>';
		
	if ( is_front_page() || is_home() ) {
		$sitename = '<h1 class="site-title">'.$link.'</h1>'."\n";
	} else {
		$sitename = '<h1 class="site-title">'.$link.'</h1>'."\n";
	}
		
	return $sitename;
}

?>